import awsSdk from 'aws-sdk';
import util from 'util';
import lodash from 'lodash';
import mimeTypes from 'mime-types';
import randomatic from 'randomatic';
import zlib from 'zlib';
import debug$5 from 'debug';
import botiumCore from 'botium-core';

const debug$4 = debug$5('botium-connector-lex');
const Capabilities = {
  LEX_VERSION: 'LEX_VERSION',
  LEX_REGION: 'LEX_REGION',
  LEX_ACCESS_KEY_ID: 'LEX_ACCESS_KEY_ID',
  LEX_SECRET_ACCESS_KEY: 'LEX_SECRET_ACCESS_KEY',
  LEX_LOCALE: 'LEX_LOCALE',
  LEX_PROJECT_NAME: 'LEX_PROJECT_NAME',
  LEX_PROJECT_ALIAS: 'LEX_PROJECT_ALIAS',
  LEX_PROJECT_VERSION: 'LEX_PROJECT_VERSION',
  LEX_SESSION_ATTRIBUTES: 'LEX_SESSION_ATTRIBUTES',
  LEX_REQUEST_ATTRIBUTES: 'LEX_REQUEST_ATTRIBUTES',
  LEX_ACCEPT: 'LEX_ACCEPT',
  LEX_CONTENTTYPE_TEXT: 'LEX_CONTENTTYPE_TEXT',
  LEX_CONTENTTYPE_AUDIO: 'LEX_CONTENTTYPE_AUDIO'
};
const Defaults$2 = {
  [Capabilities.LEX_VERSION]: 'V1',
  [Capabilities.LEX_LOCALE]: 'en_US',
  [Capabilities.LEX_ACCEPT]: 'text/plain; charset=utf-8',
  [Capabilities.LEX_CONTENTTYPE_TEXT]: 'text/plain; charset=utf-8',
  [Capabilities.LEX_CONTENTTYPE_AUDIO]: 'audio/l16; rate=16000; channels=1'
};
const gzipAndBase64 = obj => zlib.gzipSync(JSON.stringify(obj)).toString('base64');
const base64AndUnzip = str => JSON.parse(zlib.gunzipSync(Buffer.from(str, 'base64')));
class BotiumConnectorLex {
  constructor({
    queueBotSays,
    caps
  }) {
    this.queueBotSays = queueBotSays;
    this.caps = Object.assign({}, Defaults$2, caps);
  }
  async Validate() {
    debug$4('Validate called');
    if (!this._isV1() && !this._isV2()) throw new Error('LEX_VERSION capability V1 or V2 required');
    if (!this.caps[Capabilities.LEX_REGION]) throw new Error('LEX_REGION capability required');
    if (!this.caps[Capabilities.LEX_ACCESS_KEY_ID]) throw new Error('LEX_ACCESS_KEY_ID capability required');
    if (!this.caps[Capabilities.LEX_SECRET_ACCESS_KEY]) throw new Error('LEX_SECRET_ACCESS_KEY capability required');
    if (!this.caps[Capabilities.LEX_PROJECT_NAME]) throw new Error('LEX_PROJECT_NAME capability required');
    if (!this.caps[Capabilities.LEX_PROJECT_ALIAS]) throw new Error('LEX_PROJECT_ALIAS capability required');
    if (this._isV2() && !this.caps[Capabilities.LEX_LOCALE]) throw new Error('LEX_LOCALE capability required');
  }
  _isV1() {
    return this.caps[Capabilities.LEX_VERSION] === 'V1';
  }
  _isV2() {
    return this.caps[Capabilities.LEX_VERSION] === 'V2';
  }
  async Build() {
    debug$4('Build called');
    if (this._isV1()) {
      this.client = new awsSdk.LexRuntime({
        apiVersion: '2016-11-28',
        region: this.caps[Capabilities.LEX_REGION],
        accessKeyId: this.caps[Capabilities.LEX_ACCESS_KEY_ID],
        secretAccessKey: this.caps[Capabilities.LEX_SECRET_ACCESS_KEY]
      });
    } else {
      this.client = new awsSdk.LexRuntimeV2({
        apiVersion: '2020-08-07',
        region: this.caps[Capabilities.LEX_REGION],
        accessKeyId: this.caps[Capabilities.LEX_ACCESS_KEY_ID],
        secretAccessKey: this.caps[Capabilities.LEX_SECRET_ACCESS_KEY]
      });
    }
  }
  Start() {
    debug$4('Start called');
    this.lexUserId = 'chatbot-demo-' + randomatic('Aa', 5);
    const sessionAttributesfromCaps = this.caps[Capabilities.LEX_SESSION_ATTRIBUTES];
    if (sessionAttributesfromCaps) {
      if (typeof sessionAttributesfromCaps === 'string') {
        try {
          this.sessionAttributes = JSON.parse(sessionAttributesfromCaps);
        } catch (ex) {
          throw new Error('The type LEX_SESSION_ATTRIBUTES capability is invalid. Cant be converted to JSON');
        }
      } else {
        this.sessionAttributes = sessionAttributesfromCaps;
      }
      if (typeof this.sessionAttributes !== 'object') {
        throw new Error('The type LEX_SESSION_ATTRIBUTES capability is invalid. It must be object, or an object as string');
      }
    } else {
      this.sessionAttributes = {};
    }
    const requestAttributesfromCaps = this.caps[Capabilities.LEX_REQUEST_ATTRIBUTES];
    if (requestAttributesfromCaps) {
      if (typeof requestAttributesfromCaps === 'string') {
        try {
          this.requestAttributes = JSON.parse(requestAttributesfromCaps);
        } catch (ex) {
          throw new Error('The type LEX_REQUEST_ATTRIBUTES capability is invalid. Cant be converted to JSON');
        }
      } else {
        this.requestAttributes = requestAttributesfromCaps;
      }
      if (typeof this.requestAttributes !== 'object') {
        throw new Error('The type LEX_REQUEST_ATTRIBUTES capability is invalid. It must be object, or an object as string');
      }
    } else {
      this.requestAttributes = {};
    }
  }
  _handleResponseV1(data) {
    debug$4(`Lex V1 answered: ${JSON.stringify(lodash.omit(data, ['audioStream']), null, 2)}`);
    this.sessionAttributes = data.sessionAttributes;
    const structuredResponse = {
      sender: 'bot',
      messageText: data.message,
      nlp: {},
      sourceData: data
    };
    if (data.intentName) {
      structuredResponse.nlp.intent = {
        name: data.intentName
      };
    } else {
      structuredResponse.nlp.intent = {
        incomprehension: true
      };
    }
    if (data.slots) {
      structuredResponse.nlp.entities = Object.entries(data.slots).filter(([name, value]) => value != null).map(([name, value]) => {
        return {
          name,
          value
        };
      });
    } else {
      structuredResponse.nlp.entities = [];
    }
    if (data.audioStream && !data.contentType.startsWith('text')) {
      let ext = null;
      if (data.contentType === 'audio/mpeg') {
        ext = 'mp3';
      } else if (data.contentType === 'audio/ogg') {
        ext = 'ogg';
      } else if (data.contentType === 'audio/pcm') {
        ext = 'wav';
      } else {
        ext = mimeTypes.extension(data.contentType);
      }
      if (ext) {
        structuredResponse.media = [{
          mediaUri: `data:${data.contentType};base64,${data.audioStream.toString('base64')}`,
          altText: `lex-response.${ext}`,
          mimeType: data.contentType
        }];
      }
    }
    if (data.responseCard) {
      if (data.responseCard.contentType === 'application/vnd.amazonaws.card.generic') {
        if (data.responseCard.genericAttachments) {
          structuredResponse.cards = data.responseCard.genericAttachments.map(card => ({
            text: card.title,
            subtext: card.subTitle,
            image: card.imageUrl && {
              mediaUri: card.imageUrl
            } || null,
            buttons: card.buttons && card.buttons.map(b => ({
              text: b.text,
              payload: b.value
            })) || []
          }));
        }
      }
    }
    setTimeout(() => this.queueBotSays(structuredResponse), 0);
  }
  _handleResponseV2(data) {
    debug$4(`Lex V2 answered: ${JSON.stringify(lodash.omit(data, ['audioStream']), null, 2)}`);
    this.sessionState = data.sessionState;
    const _extractNlp = structuredResponse => {
      if (data.interpretations && data.interpretations.length > 0) {
        const i0 = data.interpretations[0];
        if (i0.intent) {
          structuredResponse.nlp.intent = {
            name: i0.intent.name,
            confidence: i0.nluConfidence && i0.nluConfidence.score,
            incomprehension: i0.intent.name === 'FallbackIntent'
          };
          if (i0.intent.slots) {
            structuredResponse.nlp.entities = Object.entries(i0.intent.slots).filter(([name, value]) => value != null).map(([name, value]) => {
              return {
                name,
                value: value.value.interpretedValue || value.value.originalValue
              };
            });
          } else {
            structuredResponse.nlp.entities = [];
          }
        }
      }
      if (!structuredResponse.nlp.intent) {
        structuredResponse.nlp.intent = {
          incomprehension: true
        };
      }
      return structuredResponse;
    };
    if (data.messages && data.messages.length > 0) {
      for (const message of data.messages || []) {
        const structuredResponse = {
          sender: 'bot',
          nlp: {},
          sourceData: data
        };
        _extractNlp(structuredResponse);
        if (message.contentType === 'PlainText') {
          structuredResponse.messageText = message.content;
        } else if (message.contentType === 'ImageResponseCard' && message.imageResponseCard) {
          structuredResponse.cards = [{
            text: message.imageResponseCard.title,
            subtext: message.imageResponseCard.subTitle,
            image: message.imageResponseCard.imageUrl && {
              mediaUri: message.imageResponseCard.imageUrl
            } || null,
            buttons: message.imageResponseCard.buttons && message.imageResponseCard.buttons.map(b => ({
              text: b.text,
              payload: b.value
            })) || []
          }];
        }
        const contentType = this.caps[Capabilities.LEX_ACCEPT];
        if (data.audioStream && !contentType.startsWith('text')) {
          let ext = null;
          if (contentType === 'audio/mpeg') {
            ext = 'mp3';
          } else if (contentType === 'audio/ogg') {
            ext = 'ogg';
          } else if (contentType === 'audio/pcm') {
            ext = 'wav';
          } else {
            ext = mimeTypes.extension(contentType);
          }
          if (ext) {
            structuredResponse.media = [{
              mediaUri: `data:${contentType};base64,${data.audioStream.toString('base64')}`,
              altText: `lex-response.${ext}`,
              mimeType: contentType
            }];
          }
        }
        setTimeout(() => this.queueBotSays(structuredResponse), 0);
      }
    } else {
      setTimeout(() => this.queueBotSays(_extractNlp({
        sender: 'bot',
        nlp: {},
        sourceData: data
      })), 0);
    }
  }
  async UserSays(msg) {
    debug$4('UserSays called');
    const params = this._isV1() ? {
      botName: this.caps[Capabilities.LEX_PROJECT_NAME],
      botAlias: this.caps[Capabilities.LEX_PROJECT_ALIAS],
      userId: this.lexUserId,
      sessionAttributes: this.sessionAttributes,
      requestAttributes: this.requestAttributes
    } : {
      botId: this.caps[Capabilities.LEX_PROJECT_NAME],
      botAliasId: this.caps[Capabilities.LEX_PROJECT_ALIAS],
      localeId: this.caps[Capabilities.LEX_LOCALE],
      sessionId: this.lexUserId,
      sessionState: this.sessionState || {
        sessionAttributes: this.sessionAttributes
      },
      requestAttributes: this.requestAttributes
    };
    if (msg.SET_LEX_SESSION_ATTRIBUTE) {
      if (this._isV1()) {
        params.sessionAttributes = Object.assign({}, params.sessionAttributes, msg.SET_LEX_SESSION_ATTRIBUTE);
      } else {
        params.sessionState.sessionAttributes = Object.assign({}, params.sessionState.sessionAttributes || {}, msg.SET_LEX_SESSION_ATTRIBUTE);
      }
    }
    if (msg.SET_LEX_REQUEST_ATTRIBUTE) {
      params.requestAttributes = Object.assign({}, params.requestAttributes, msg.SET_LEX_REQUEST_ATTRIBUTE);
    }
    if (msg.media && msg.media.length > 0) {
      const media = msg.media[0];
      if (!media.buffer) {
        return Promise.reject(new Error(`Media attachment ${media.mediaUri} not downloaded`));
      }
      if (!media.mimeType || !media.mimeType.startsWith('audio')) {
        return Promise.reject(new Error(`Media attachment ${media.mediaUri} mime type ${media.mimeType || '<empty>'} not supported (audio only)`));
      }
      if (this._isV1()) {
        params.accept = this.caps[Capabilities.LEX_ACCEPT];
        params.contentType = this.caps[Capabilities.LEX_CONTENTTYPE_AUDIO];
      } else {
        params.responseContentType = this.caps[Capabilities.LEX_ACCEPT];
        params.requestContentType = this.caps[Capabilities.LEX_CONTENTTYPE_AUDIO];
        params.sessionState = gzipAndBase64(params.sessionState);
        params.requestAttributes = gzipAndBase64(params.requestAttributes);
      }
      params.inputStream = media.buffer;
      if (!msg.attachments) {
        msg.attachments = [];
      }
      msg.attachments.push({
        name: media.mediaUri,
        mimeType: media.mimeType,
        base64: media.buffer.toString('base64')
      });
      msg.sourceData = params;
      debug$4(`Lex posting audio: ${util.inspect(lodash.omit(params, ['inputStream']))}`);
      return new Promise((resolve, reject) => {
        if (this._isV1()) {
          this.client.postContent(params, (err, data) => {
            if (err) return reject(new Error(`Lex V1 answered with error: ${err.message}`));
            if (data) {
              try {
                this._handleResponseV1(data);
              } catch (err) {
                return reject(new Error(`Lex V2 error: ${err.message}`));
              }
            }
            resolve();
          });
        } else {
          this.client.recognizeUtterance(params, (err, data) => {
            if (err) return reject(new Error(`Lex V1 answered with error: ${err.message}`));
            if (data) {
              try {
                if (data.messages) data.messages = base64AndUnzip(data.messages);
                if (data.interpretations) data.interpretations = base64AndUnzip(data.interpretations);
                if (data.sessionState) data.sessionState = base64AndUnzip(data.sessionState);
                if (data.requestAttributes) data.requestAttributes = base64AndUnzip(data.requestAttributes);
                if (data.inputTranscript) data.inputTranscript = base64AndUnzip(data.inputTranscript);
                this._handleResponseV2(data);
              } catch (err) {
                return reject(new Error(`Lex V2 error: ${err.message}`));
              }
            }
            resolve();
          });
        }
      });
    } else {
      if (this._isV1()) {
        params.inputText = msg.messageText;
      } else {
        params.text = msg.messageText;
      }
      msg.sourceData = params;
      debug$4(`Lex posting text: ${util.inspect(params)}`);
      return new Promise((resolve, reject) => {
        if (this._isV1()) {
          this.client.postText(params, (err, data) => {
            if (err) return reject(new Error(`Lex V1 answered with error: ${err.message}`));
            if (data) {
              try {
                this._handleResponseV1(data);
              } catch (err) {
                return reject(new Error(`Lex V1 error: ${err.message}`));
              }
            }
            resolve();
          });
        } else {
          this.client.recognizeText(params, (err, data) => {
            if (err) return reject(new Error(`Lex V2 answered with error: ${err.message}`));
            if (data) {
              try {
                this._handleResponseV2(data);
              } catch (err) {
                return reject(new Error(`Lex V2 error: ${err.message}`));
              }
            }
            resolve();
          });
        }
      });
    }
  }
  Stop() {
    debug$4('Stop called');
    this.lexUserId = null;
    this.sessionAttributes = null;
    this.sessionState = null;
    this.requestAttributes = null;
  }
  Clean() {
    debug$4('Clean called');
    this.client = null;
  }
}
var connector = BotiumConnectorLex;
var Defaults_1 = Defaults$2;
var Capabilities_1 = Capabilities;
connector.Defaults = Defaults_1;
connector.Capabilities = Capabilities_1;

var en = {
	"AMAZON.DATE": [
		"today",
		"tomorrow",
		"next week",
		"next month",
		"next year",
		"september",
		"july fifth",
		"november twenty-fifth",
		"next monday"
	],
	"AMAZON.DURATION": [
		"ten minutes",
		"five hours",
		"three days",
		"eight weeks",
		"seven years"
	],
	"AMAZON.FOUR_DIGIT_NUMBER": [
		"six oh four five",
		"six zero four five",
		"six oh forty five",
		"sixty forty five",
		"six thousand forty five"
	],
	"AMAZON.NUMBER": [
		"three",
		"ten",
		"fifty five",
		"one oh four",
		"one hundred four",
		"one hundred and four",
		"five thousand two hundred and thirty five",
		"nine eight zero three four"
	],
	"AMAZON.Ordinal": [
		"third",
		"tenth",
		"first",
		"fifteenth"
	],
	"AMAZON.PhoneNumber": [
		"plus one five zero nine five five five one two one two",
		"one five zero nine five five five one two one two",
		"five zero nine five five five one two one two",
		"five five five one two one two"
	],
	"AMAZON.TIME": [
		"noon",
		"midnight",
		"six",
		"four twenty three in the morning",
		"five am",
		"one thirty in the afternoon",
		"two fifteen pm",
		"eleven fifty nine at night",
		"this morning",
		"now"
	]
};
var de = {
	"AMAZON.DATE": [
		"heute",
		"morgen",
		"nächste woche",
		"nächsten monat",
		"nächstes jahr"
	],
	"AMAZON.DURATION": [
		"zehn minuten",
		"fünf stunden"
	],
	"AMAZON.FOUR_DIGIT_NUMBER": [
		"sechs null vier fünf",
		"sechs vierzig fünf",
		"sechstausend fünfundvierzig"
	],
	"AMAZON.NUMBER": [
		"drei",
		"fünfundfünfzig",
		"hundertvier",
		"hundertundvier"
	],
	"AMAZON.Ordinal": [
		"dritter",
		"zehnter",
		"erster"
	],
	"AMAZON.PhoneNumber": [
		"null sechs sieben sechs drei drei zwei drei sieben vier eins"
	],
	"AMAZON.TIME": [
		"mitternacht",
		"um sechs",
		"neun am morgen",
		"jetzt"
	]
};
var slottypesamples = {
	en: en,
	de: de
};

var slottypesamples$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  en: en,
  de: de,
  'default': slottypesamples
});

var builtinslottypesamples = {
	"en-au": {
	"AMAZON.Actor": [
		"Hugh Jackman",
		"Scarlett Johansson",
		"Luke Hemsworth",
		"Matt Damon",
		"Kristen Bell",
		"Chris Pratt",
		"Anna Farris",
		"Rebel Wilson",
		"Barry Humphries",
		"Nikolai Nikolaeff",
		"Michael Caton",
		"Vince Colosimo",
		"Toni Collette",
		"Glenn Robbins",
		"Jane Turner"
	],
	"AMAZON.Airline": [
		"Qantas",
		"Regional Express Airlines",
		"Virgin Australia",
		"Jetstar",
		"Airnorth",
		"Emirates",
		"American Airlines",
		"Malaysia Airlines",
		"AirAsia",
		"Etihad Airways"
	],
	"AMAZON.Airport": [
		"Melbourne Airport",
		"Brisbane Airport",
		"Adelaide Airport",
		"Perth Airport",
		"Los Angeles International Airport",
		"John F. Kennedy International Airport",
		"Heathrow Airport",
		"O'Hare International Airport",
		"Sydney Airport",
		"Paris Charles de Gaulle Airport"
	],
	"AMAZON.Animal": [
		"Wombat",
		"Quokka",
		"Echidna",
		"Great White Shark",
		"Tasmanian Devil",
		"Cassowary",
		"Platypus",
		"Goanna",
		"Kookaburra",
		"Koala",
		"Kangaroo",
		"Goat",
		"Pelican",
		"Penguin",
		"Dingo"
	],
	"AMAZON.Artist": [
		"Takashi Murakami",
		"Ben Quilty",
		"Lin Onus",
		"Brett Whiteley",
		"William Dobell",
		"Salvador Dali",
		"Frida Kahlo",
		"Pablo Picasso",
		"Edvard Munch",
		"Andy Warhol",
		"Roy Lichtenstein",
		"Vincent van Gogh",
		"Georgia O'Keeffe",
		"Jackson Pollock",
		"Storm Thorgerson"
	],
	"AMAZON.Author": [
		"Mem Fox",
		"John Marsden",
		"Patrick White",
		"Henry Lawson",
		"Banjo Paterson",
		"Peter Carey"
	],
	"AMAZON.Book": [
		"Looking for Alibrandi",
		"The Magic Pudding",
		"The Fatal Shore: The Epic of Australia's Founding",
		"Tomorrow, When the War Began",
		"Where the Wild Things Are",
		"Cloudstreet",
		"Seven Little Australians",
		"True History of the Kelly Gang",
		"The Book Thief",
		"The Dressmaker",
		"Obernewtyn",
		"Monkey Grip",
		"The Great Gatsby",
		"The Da Vinci Code",
		"Alice's Adventures in Wonderland"
	],
	"AMAZON.City": [
		"Sydney",
		"Darwin",
		"Newcastle",
		"Wagga Wagga",
		"Wollongong",
		"Port Macquarie"
	],
	"AMAZON.Color": [
		"Red",
		"Blue",
		"Green",
		"Indigo",
		"Vermillion",
		"Chartreuse",
		"Pewter",
		"Saffron",
		"Magenta",
		"Turquoise",
		"Purple",
		"Orange",
		"Yellow",
		"Pink",
		"fuchsia"
	],
	"AMAZON.Corporation": [
		"Telstra",
		"Optus",
		"Foxtel",
		"Commonwealth Bank of Australia",
		"Qantas Airways",
		"Wesfarmers Limited",
		"Westpac Banking Corporation",
		"Mirvac Group",
		"BHP Billiton Limited",
		"Rio Tinto Limited",
		"Woolworths Limited",
		"Westfield Group",
		"Coles",
		"Fairfax Media Limited",
		"Franklins"
	],
	"AMAZON.Country": [
		"China",
		"India",
		"United States",
		"Australia",
		"New Zealand",
		"Indonesia",
		"Great Britian",
		"Mexico",
		"Brazil",
		"Canada"
	],
	"AMAZON.CreativeWorkType": [
		"photograph",
		"pottery",
		"comic",
		"play",
		"film",
		"song",
		"show",
		"sculpture",
		"painting",
		"book"
	],
	"AMAZON.DayOfWeek": [
		"Monday",
		"Thursday",
		"Saturday",
		"Tuesday",
		"Wednesday",
		"Sunday",
		"Friday"
	],
	"AMAZON.FictionalCharacter": [
		"DCI John Luther",
		"Blinky Bill",
		"Barry McKenzie",
		"Leopold Bloom",
		"Superman",
		"Batman",
		"Harry Potter",
		"Homer simpson",
		"Sherlock Holmes",
		"Nemo"
	],
	"AMAZON.FirstName": [
		"John",
		"Jack",
		"Oliver",
		"Samuel",
		"Lachlan",
		"Daniel"
	],
	"AMAZON.Food": [
		"Iced VoVo",
		"Lamington",
		"Promite",
		"Fairy Bread",
		"Meat Pie",
		"Sausage Roll",
		"Tomato Sauce",
		"Custard Tart",
		"Beetroot",
		"Hot Chips",
		"Vegemite",
		"Crumpet",
		"Milk Arrowroot",
		"Kinder Surprise",
		"Turkish Delight"
	],
	"AMAZON.Genre": [
		"Aussie",
		"Australian",
		"Kiwi",
		"Rap",
		"Chinese",
		"Soul",
		"Disco",
		"Romance",
		"Soapie",
		"Superhero",
		"EDM",
		"Dance",
		"Action",
		"Sci-Fi",
		"K-Pop"
	],
	"AMAZON.Language": [
		"English",
		"Mandarin",
		"Cantonese",
		"Arabic",
		"Vietnamese",
		"Greek",
		"Tagalog",
		"Italian",
		"Hindi",
		"Spanish"
	],
	"AMAZON.Month": [
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December"
	],
	"AMAZON.Movie": [
		"Avatar",
		"Crackerjack",
		"Pocahontas",
		"Gallipoli",
		"The Castle",
		"Me, Myself & Irene",
		"Rabbit-Proof Fence",
		"Pleasantville",
		"Chopper",
		"Pan's Labyrinth",
		"House of Flying Daggers",
		"Austin Powers in Goldmember",
		"You Only Live Twice",
		"Spirited Away",
		"The Avengers"
	],
	"AMAZON.MusicAlbum": [
		"…Baby One More Time",
		"Places Like This",
		"Diorama",
		"Wolfmother",
		"Business as Usual",
		"The Secret Life Of…",
		"Back in Black",
		"Ballbreaker",
		"True Colours",
		"Get Born",
		"The Boatman's Call",
		"Walking on a Dream"
	],
	"AMAZON.MusicGroup": [
		"Wolfmother",
		"The Veronicas",
		"Delta Goodrem",
		"Men at Work",
		"One Direction",
		"Green Day",
		"U2",
		"The beatles",
		"Owl City",
		"Bon Jovi"
	],
	"AMAZON.Musician": [
		"Vance Joy",
		"Gotye",
		"Kylie Minogue",
		"Sia",
		"Missy Higgins",
		"Keith Urban",
		"Jimmy Barnes",
		"Natalie Imbruglia",
		"Olivia Newton-John",
		"John Farnham"
	],
	"AMAZON.MusicRecording": [
		"Highway to Hell",
		"Don't Dream It's Over",
		"Born in the USA",
		"Despacito",
		"Stairway to Heaven",
		"Jailhouse Rock",
		"Good Vibrations",
		"Fly Me to the Moon",
		"High Hopes",
		"One Kiss"
	],
	"AMAZON.Person": [
		"Malcolm Turnbull",
		"Magda Szubanski",
		"Ned Kelly",
		"Steve Irwin",
		"Rose Byrne",
		"Judith Lucy",
		"Jim Jefferies",
		"John Howard",
		"Dawn Fraser",
		"Ian Thorpe",
		"Cathy Freeman",
		"Hugh Jackman",
		"Shannon Noll",
		"Kevin Rudd",
		"Shane Warne"
	],
	"AMAZON.RadioChannel": [
		"2GB",
		"KIIS 101.1",
		"Nova 96.9",
		"ABC Jazz",
		"BBC World Service",
		"Radio Taiwan International",
		"Radio New Zealand",
		"China Radio International",
		"BBC Radio 1",
		"Sky Radio"
	],
	"AMAZON.Region": [
		"New South Wales",
		"Blue Mountains",
		"Central Coast",
		"Arnhem Land",
		"Gippsland",
		"Northern Territory"
	],
	"AMAZON.Room": [
		"Bedroom",
		"Lounge Room",
		"Wine Cellar",
		"Library",
		"Dining Room",
		"Kitchen",
		"Study",
		"Office",
		"Laundry",
		"Bathroom",
		"Basement",
		"Foyer",
		"Living Room",
		"Garage",
		"Hallway"
	],
	"AMAZON.Sport": [
		"Australian Football",
		"Rugby League",
		"Soccer",
		"Cricket",
		"Tennis",
		"Swimming",
		"Rugby Union",
		"Basketball",
		"Horse Racing",
		"Motorsport"
	],
	"AMAZON.StreetName": [
		"Flinders Street",
		"Pitt Street",
		"Canberra Avenue",
		"Mannigham Road",
		"Oxford Street",
		"George Street",
		"Pennant Hills Road",
		"Mitcham Road",
		"Mundaring Weird Road",
		"Hay Street",
		"William Street",
		"Knuckey Street",
		"Elizabeth Street",
		"Capital Circle",
		"Market Street"
	],
	"AMAZON.TVSeries": [
		"13 Reasons Why",
		"Poldark",
		"Black Mirror",
		"Narcos",
		"Wentworth",
		"Glitch",
		"Oz",
		"Twin Peaks",
		"The Prisoner",
		"Breaking Bad"
	],
	"AMAZON.VideoGame": [
		"Call of Duty: Infinite Warfare",
		"Crash Bandicoot: N.Sane Trilogy",
		"Far Cry 5",
		"The Sims 4",
		"Wolfenstein II: The New Colossus",
		"Middle Earth: Shadow of War",
		"Wolfenstein",
		"Angry Birds",
		"Fortnite",
		"Snake"
	]
},
	"en-ca": {
	"AMAZON.Actor": [
		"Keanu Reeves",
		"Jim Carrey",
		"William Shatner",
		"Ryan Gosling",
		"Pamela Anderson",
		"Mike Myers",
		"Michael J. Fox",
		"Seth Rogen",
		"Ryan Reynolds",
		"Rachel McAdams"
	],
	"AMAZON.Airline": [
		"Air Canada",
		"WestJet",
		"Jazz Air",
		"Central Mountain Air",
		"WestCoast Air",
		"Air North",
		"Calm Air",
		"Porter Airlines",
		"Air Transat",
		"CanJet"
	],
	"AMAZON.Airport": [
		"Calgary International Airport",
		"Edmonton International Airport",
		"Halifax International Airport",
		"Kelowna International Airport",
		"Kenora Airport",
		"Montréal–Pierre Elliott Trudeau International Airport",
		"Jean Lesage International Airport",
		"Toronto Pearson International Airport",
		"Vancouver International Airport",
		"Winnipeg International Airport"
	],
	"AMAZON.Animal": [
		"beaver",
		"Canada goose",
		"caribou",
		"beluga whale",
		"lynx",
		"garter snake",
		"grizzly bear",
		"monarch butterfly",
		"puffin",
		"raccoon"
	],
	"AMAZON.Artist": [
		"Tom Thomson",
		"Emily Carr",
		"Jean-Paul Riopelle",
		"Alex Colville",
		"Michael Snow",
		"Kazuo Nakamura",
		"Franklin Carmichael",
		"David Milne",
		"F. H. Varley",
		"Victor Hugo"
	],
	"AMAZON.AT_CITY": [
		"graz",
		"vienna"
	],
	"AMAZON.AT_REGION": [
		"nideristaraich",
		"steiermark"
	],
	"AMAZON.Book": [
		"The Handmaid's Tale",
		"Anne of Green Gables",
		"Cat's Eye",
		"Life of Pi",
		"The English Patient",
		"A Complicated Kindness",
		"Fifth Business",
		"Three Day Road",
		"Station Eleven",
		"The Edible Woman"
	],
	"AMAZON.City": [
		"Toronto",
		"Montreal",
		"Calgary",
		"Ottawa",
		"London"
	],
	"AMAZON.Color": [
		"Red",
		"Blue",
		"Green",
		"Indigo",
		"Vermillion",
		"Chartreuse",
		"Saffron",
		"Pewter",
		"Magenta",
		"Fuchsia",
		"Turquoise",
		"Purple",
		"Orange",
		"Yellow"
	],
	"AMAZON.Corporation": [
		"Royal Bank of Canada",
		"Toronto-Dominion Bank",
		"Bank of Montreal",
		"Imperial Oil",
		"Suncor Energy",
		"Canadian National Railway",
		"Potash Corporation",
		"Husky Energy",
		"Rogers Communications",
		"Goldcorp Inc."
	],
	"AMAZON.Country": [
		"China",
		"India",
		"United States",
		"Australia",
		"Russia",
		"Greenland",
		"Great Britain",
		"Mexico",
		"Brazil",
		"Canada"
	],
	"AMAZON.CreativeWorkType": [
		"song",
		"video",
		"movie",
		"show",
		"series",
		"episode",
		"album",
		"novel",
		"magazine",
		"poem"
	],
	"AMAZON.DayOfWeek": [
		"Monday",
		"Tuesday",
		"Friday",
		"Wednesday",
		"Thursday",
		"Saturday",
		"Sunday"
	],
	"AMAZON.DE_CITY": [
		"berlin wilmersdorf",
		"reinheim"
	],
	"AMAZON.DE_FIRST_NAME": [
		"annika",
		"jens",
		"finn"
	],
	"AMAZON.DE_REGION": [
		"freistaat bayern",
		"rheinland pfalz"
	],
	"AMAZON.EUROPE_CITY": [
		"loures",
		"kempten"
	],
	"AMAZON.FictionalCharacter": [
		"Harry Potter",
		"Wolverine",
		"Sheldon Cooper",
		"Jacob Two-Two",
		"Bob McKenzie",
		"Rebecca Pearson",
		"Jay Gatsby",
		"Anne Shirley",
		"Superman",
		"Sherlock Holmes"
	],
	"AMAZON.FirstName": [
		"John",
		"Robert",
		"David",
		"Michael",
		"William"
	],
	"AMAZON.Food": [
		"maple syrup",
		"poutine",
		"BeaverTails",
		"butter tart",
		"Nanaimo bar",
		"split pea soup",
		"peameal bacon",
		"tourtière",
		"bannock",
		"smoked meat sandwich"
	],
	"AMAZON.GB_CITY": [
		"rhymney",
		"liverpool"
	],
	"AMAZON.GB_FIRST_NAME": [
		"stephen",
		"john"
	],
	"AMAZON.GB_REGION": [
		"scotland",
		"midlands west",
		"west midlands"
	],
	"AMAZON.Genre": [
		"Horror",
		"Drama",
		"Romance",
		"Science Fiction",
		"Comedy",
		"Rock",
		"Pop",
		"Rap",
		"Jazz",
		"Classical"
	],
	"AMAZON.Language": [
		"English",
		"French",
		"Spanish",
		"Mandarin",
		"Cantonese",
		"Punjabi",
		"Tagalog",
		"Arabic",
		"German",
		"Italian"
	],
	"AMAZON.LocalBusiness": [
		"RBC",
		"Telus",
		"Jean Coutu",
		"Rona",
		"TD"
	],
	"AMAZON.Month": [
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December"
	],
	"AMAZON.Movie": [
		"The Dead Zone",
		"A History of Violence",
		"The Fly",
		"Brooklyn",
		"Meatballs",
		"The Hurricane",
		"Resident Evil: Afterlife",
		"Mama",
		"My Big Fat Greek Wedding",
		"Dead Ringers"
	],
	"AMAZON.MusicAlbum": [
		"Thriller",
		"Jagged Little Pill",
		"21",
		"Recovery",
		"Views",
		"1989",
		"Revolver",
		"Nevermind",
		"Let Go",
		"Abbey Road"
	],
	"AMAZON.MusicGroup": [
		"Rush",
		"Three Days Grace",
		"The Guess Who",
		"Arcade Fire",
		"Marianas Trench",
		"Nickelback",
		"Simple Plan",
		"Bachman-Turner Overdrive",
		"Sum 41",
		"U2"
	],
	"AMAZON.Musician": [
		"Kardinal Offishall",
		"K'naan",
		"The Weeknd",
		"Bryan Adams",
		"Céline Dion",
		"Shania Twain",
		"Sarah McLachlan",
		"Avril Lavigne",
		"Leonard Cohen",
		"Neil Young"
	],
	"AMAZON.MusicRecording": [
		"Call Me Maybe",
		"Started From The Bottom",
		"Summer of '69",
		"Hallelujah",
		"Baby",
		"Ironic",
		"Body Like a Back Road",
		"I'll Be There",
		"Feel it Still",
		"One Kiss"
	],
	"AMAZON.Person": [
		"Justin Trudeau",
		"Wilfrid Laurier",
		"Gordon Downie",
		"Geddy Lee",
		"Céline Dion",
		"Alessia Cara",
		"George Stroumboulopoulos",
		"Wayne Gretzky",
		"Alanis Morissette",
		"Sidney Crosby"
	],
	"AMAZON.RadioChannel": [
		"CBC Radio One",
		"CBC Music",
		"Ici Radio-Canada Première",
		"Ici Musique",
		"TSN Radio",
		"NRJ",
		"Rouge FM",
		"Native Communications",
		"Aboriginal Voices",
		"Radio Canada International"
	],
	"AMAZON.Region": [
		"Manitoba",
		"Nova Scotia",
		"Yukon",
		"Alberta",
		"Nunavut"
	],
	"AMAZON.Room": [
		"garage",
		"kitchen",
		"washroom",
		"bathroom",
		"office",
		"bedroom",
		"studio",
		"dining room",
		"classroom",
		"living room"
	],
	"AMAZON.StreetName": [
		"Main Street",
		"John Street",
		"King Street",
		"Queen Street",
		"Yonge Street"
	],
	"AMAZON.TVSeries": [
		"Degrassi",
		"Trailer Park Boys",
		"Orphan Black",
		"Saving Hope",
		"Heartland",
		"Bellevue",
		"Motive",
		"Murdoch Mysteries",
		"Rookie Blue",
		"19-2"
	],
	"AMAZON.US_CITY": [
		"seattle",
		"new york",
		"n.y.c."
	],
	"AMAZON.US_FIRST_NAME": [
		"john",
		"eric",
		"steve",
		"stephen",
		"annie"
	],
	"AMAZON.US_STATE": [
		"alabama",
		"alaska",
		"illinois",
		"W.A.",
		"i.l.",
		"guam",
		"district of columbia"
	],
	"AMAZON.VideoGame": [
		"Assassin's Creed",
		"Watch Dogs",
		"Far Cry",
		"Mass Effect",
		"Max Payne",
		"Prince of Persia",
		"Star Wars: The Old Republic",
		"Batman: Arkham Origins",
		"Overwatch",
		"Dragon Age: Inquisition"
	]
},
	"en-gb": {
	"AMAZON.Actor": [
		"Daniel Craig",
		"Tom Hardy",
		"Sean Connery",
		"Anthony Hopkins",
		"David Tennant",
		"Benedict Cumberbatch",
		"Emma Watson",
		"Tom Hiddleston",
		"Ian McKellen",
		"Patrick Stewart",
		"Emma Thompson",
		"Judi Dench",
		"Kiera Knightley",
		"Sean Bean",
		"Idris Elba"
	],
	"AMAZON.Airline": [
		"EasyJet",
		"British Airways",
		"FlyBe",
		"Virgin Atlantic",
		"Thomas Cook Airlines",
		"Emirates",
		"Singapore Airlines",
		"Etihad Airways",
		"Virgin Australia",
		"American Airlines"
	],
	"AMAZON.Airport": [
		"Heathrow Airport",
		"Gatwick Airport",
		"London Stansted Airport",
		"Luton Airport",
		"Edinburgh Airport",
		"Hartsfield-Jackson Atlanta International Airport",
		"Beijing Capital International Airport",
		"Dubai International Airport",
		"O'Hare International Airport",
		"Tokyo Haneda Airport"
	],
	"AMAZON.Animal": [
		"Dog",
		"Cat",
		"Horse",
		"Cow",
		"Pig",
		"Chicken",
		"Frog",
		"Fox",
		"Deer",
		"Mouse",
		"Badger",
		"Hedgehog",
		"Sheep",
		"Duck",
		"Squirrel"
	],
	"AMAZON.Artist": [
		"Damien Hirst",
		"Banksy",
		"J. M. W. Turner",
		"Tracey Emin",
		"David Hockney",
		"Henry Moore",
		"Anish Kapoor",
		"Francis Bacon",
		"Lucien Freud",
		"William Morris",
		"Alan Moore",
		"Quentin Blake",
		"William Blake",
		"Barbara Hepworth"
	],
	"AMAZON.AT_CITY": [
		"graz",
		"vienna"
	],
	"AMAZON.AT_REGION": [
		"nideristaraich",
		"steiermark"
	],
	"AMAZON.Book": [
		"Pride and Prejudice",
		"Alice's Adventures in Wonderland",
		"The Lord of the Rings",
		"The Wind in the Willows",
		"1984",
		"The Grapes of Wrath",
		"The Shadow of the Wind",
		"Life of Pi",
		"Don Quixote",
		"The Little Prince"
	],
	"AMAZON.City": [
		"London",
		"Birmingham",
		"Glasgow",
		"Leeds",
		"Bristol"
	],
	"AMAZON.Color": [
		"red",
		"green",
		"blue",
		"yellow",
		"orange",
		"violet",
		"purple",
		"brown",
		"black",
		"white",
		"grey",
		"pink",
		"teal",
		"fuschia",
		"maroon"
	],
	"AMAZON.Corporation": [
		"BP",
		"British Petroleum",
		"Legal and General",
		"Prudential",
		"Aviva",
		"Tesco",
		"Lloyds",
		"Vodafone",
		"Unilever",
		"Southern Scottish Electric",
		"GlaxoSmithKline",
		"Barclays",
		"BT",
		"British Telecom",
		"BAE systems"
	],
	"AMAZON.Country": [
		"China",
		"India",
		"United States of America",
		"USA",
		"Brazil",
		"Pakistan",
		"Russia",
		"Mexico",
		"Japan",
		"Germany",
		"France",
		"United Kingdom",
		"UK",
		"Italy",
		"Spain"
	],
	"AMAZON.CreativeWorkType": [
		"Song",
		"Show",
		"Film",
		"Album",
		"Novel",
		"Poem",
		"Photograph",
		"Sculpture",
		"Painting",
		"Drawing"
	],
	"AMAZON.DayOfWeek": [
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday",
		"Sunday"
	],
	"AMAZON.DE_CITY": [
		"berlin wilmersdorf",
		"reinheim"
	],
	"AMAZON.DE_FIRST_NAME": [
		"annika",
		"jens",
		"finn"
	],
	"AMAZON.DE_REGION": [
		"freistaat bayern",
		"rheinland pfalz"
	],
	"AMAZON.EUROPE_CITY": [
		"loures",
		"kempten"
	],
	"AMAZON.FictionalCharacter": [
		"Dracula",
		"Frankenstein",
		"James Bond",
		"Harry Potter",
		"Miss Havisham",
		"Paddington Bear",
		"Sherlock Holmes",
		"Ebenezer Scrooge",
		"Arthur Dent",
		"Mary Poppins",
		"Mr. Bean",
		"Basil Fawlty",
		"Willy Wonka"
	],
	"AMAZON.FirstName": [
		"Alayna",
		"Dougie",
		"Katharine",
		"Angelina",
		"Aubrey"
	],
	"AMAZON.Food": [
		"Bread",
		"Milk",
		"Sausage",
		"Bacon",
		"Egg",
		"Tomato",
		"Potato",
		"Lettuce",
		"Biscuits",
		"Peas",
		"Beans",
		"Onion",
		"Carrot",
		"Chicken",
		"Cheese"
	],
	"AMAZON.GB_CITY": [
		"rhymney",
		"liverpool"
	],
	"AMAZON.GB_FIRST_NAME": [
		"stephen",
		"john"
	],
	"AMAZON.GB_REGION": [
		"scotland",
		"midlands west",
		"west midlands"
	],
	"AMAZON.Genre": [
		"Horror",
		"Science Fiction",
		"Drama",
		"Romance",
		"Comedy",
		"Action",
		"Tragedy",
		"Rock",
		"Dance",
		"Hip Hop",
		"Classical",
		"Indie",
		"Pop",
		"R&B",
		"Jazz"
	],
	"AMAZON.Language": [
		"English",
		"Spanish",
		"Italian",
		"French",
		"German",
		"Dutch",
		"Welsh",
		"Japanese",
		"Polish",
		"Mandarin",
		"Czech",
		"Hindi",
		"Urdu",
		"Arabic",
		"Greek"
	],
	"AMAZON.Month": [
		"January",
		"March",
		"February",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December"
	],
	"AMAZON.Movie": [
		"The Dark Knight",
		"Star Wars the Force Awakens",
		"Dunkirk",
		"Harry Potter",
		"The Lord of the Rings",
		"Casino Royale",
		"Jurassic Park",
		"Titanic",
		"Shaun of the Dead",
		"Inception",
		"The Italian Job",
		"The Lion King",
		"Toy Story",
		"Trainspotting",
		"The King's Speech"
	],
	"AMAZON.MusicAlbum": [
		"Thriller",
		"Back in Black",
		"Rumours",
		"Hotel California",
		"21",
		"Purple Rain",
		"The Life of Pablo",
		"Human",
		"Sleep Well Beast",
		"Everything Now",
		"Reputation",
		"1989",
		"Face Value",
		"News of the World"
	],
	"AMAZON.MusicGroup": [
		"Queen",
		"Oasis",
		"Blur",
		"AC/DC",
		"Metallica",
		"The Beatles",
		"Coldplay",
		"The Cure",
		"Green Day",
		"Joy Division",
		"Madness",
		"Thirty Seconds to Mars",
		"Mumford & Sons",
		"Muse"
	],
	"AMAZON.Musician": [
		"Ariana Grande",
		"The Beatles",
		"The Rolling Stones",
		"Drake",
		"Adele",
		"Ed Sheeran",
		"Nicki Minaj",
		"One Direction",
		"Leona Lewis",
		"Amy Winehouse"
	],
	"AMAZON.MusicRecording": [
		"Bohemian Rhapsody",
		"Parklife",
		"Morning Glory",
		"Everything Now",
		"Thunderstruck",
		"Wonderwall",
		"Don't Look Back in Anger",
		"Perfect",
		"Galway Girl",
		"Despacito",
		"Shape of You",
		"Hello",
		"Someone Like You",
		"Set Fire to the Rain"
	],
	"AMAZON.Person": [
		"David Attenborough",
		"Stephen Fry",
		"Sherlock Holmes",
		"Charles Darwin",
		"Jeremy Clarkson",
		"Jeremy Corbyn",
		"Theresa May",
		"Stephen Hawking",
		"William Shakespeare",
		"Winston Churchill",
		"Queen Elizabeth the First",
		"Queen Victoria",
		"King Arthur",
		"King Henry the Eighth",
		"Margaret Thatcher"
	],
	"AMAZON.RadioChannel": [
		"LBC",
		"Radio One",
		"Heart",
		"Capital FM",
		"XFM",
		"Absolute Radio",
		"Classic FM",
		"TalkSPORT",
		"Kiss",
		"Virgin Radio",
		"Jazz FM",
		"magic one thousand fifty four f.m."
	],
	"AMAZON.Region": [
		"North West",
		"West Midlands",
		"South Ayrshire",
		"Wrexham",
		"Torbay"
	],
	"AMAZON.Room": [
		"kitchen",
		"living room",
		"bathroom",
		"bedroom",
		"study",
		"porch",
		"conservatory",
		"pantry",
		"dining room",
		"garage",
		"landing",
		"attic",
		"utility room",
		"hallway",
		"shed"
	],
	"AMAZON.Sport": [
		"Football",
		"Basketball",
		"Tennis",
		"Golf",
		"Rugby",
		"Badminton",
		"Cricket",
		"Hockey",
		"Boxing",
		"Surfing",
		"Cycling",
		"Horse Racing",
		"Squash",
		"Rock Climbing",
		"Rowing",
		"Abseiling"
	],
	"AMAZON.StreetName": [
		"High Street",
		"Station Road",
		"Main Street",
		"Downing Street",
		"Baker Street",
		"Park Road",
		"Church Road",
		"Mill Lane",
		"London Road",
		"Strand"
	],
	"AMAZON.TVSeries": [
		"Downton Abbey",
		"The Great British Bake Off",
		"Sherlock",
		"Doctor Who",
		"Doctor Foster",
		"Only Fools and Horses",
		"The Office",
		"Peaky Blinders",
		"Peep Show",
		"Luther",
		"Top Gear",
		"Fawlty Towers",
		"Call the Midwife"
	],
	"AMAZON.US_CITY": [
		"seattle",
		"new york",
		"n.y.c."
	],
	"AMAZON.US_FIRST_NAME": [
		"john",
		"eric",
		"steve",
		"stephen",
		"annie"
	],
	"AMAZON.US_STATE": [
		"alabama",
		"alaska",
		"illinois",
		"W.A.",
		"i.l.",
		"guam",
		"district of columbia"
	],
	"AMAZON.VideoGame": [
		"The Witcher",
		"The Last of Us",
		"Call of Duty",
		"Overwatch",
		"Minecraft",
		"Final Fantasy",
		"Assassin's Creed",
		"Super Mario Kart",
		"The Legend of Zelda: Ocarina of Time",
		"FIFA 18"
	]
},
	"en-us": {
	"AMAZON.Actor": [
		"tim roth",
		"amy adams",
		"alan rickman",
		"daniel radcliffe",
		"emma watson"
	],
	"AMAZON.AdministrativeArea": [
		"oxnard california",
		"grangeville idaho",
		"missoula",
		"boulder",
		"hurricane west virginia",
		"mason city",
		"gulfport mississippi",
		"portsmouth new hampshire"
	],
	"AMAZON.AggregateRating": [
		"four star",
		"top",
		"top five",
		"five star",
		"highly rated",
		"popular",
		"best",
		"top ten"
	],
	"AMAZON.Airline": [
		"air france",
		"british airways",
		"coyne aviation",
		"delta airlines",
		"dolphin air",
		"maestro"
	],
	"AMAZON.Airport": [
		"john f. kennedy memorial airport",
		"san francisco international airport",
		"dulles international airport",
		"logan airport",
		"sky harbor airport"
	],
	"AMAZON.Anaphor": [
		"that",
		"these",
		"this",
		"that one"
	],
	"AMAZON.Animal": [
		"funnel web spider",
		"spider monkey",
		"blister beetle",
		"opossum",
		"common frog",
		"javelina",
		"moray eel",
		"milkweed beetle"
	],
	"AMAZON.Artist": [
		"michael jackson",
		"paul mccartney",
		"justin bieber",
		"Shakespeare",
		"Ed Sheeran",
		"Lady Gaga",
		"Picasso",
		"Edgar Allan Poe",
		"Taylor Swift",
		"Kesha"
	],
	"AMAZON.AT_CITY": [
		"graz",
		"vienna"
	],
	"AMAZON.AT_REGION": [
		"nideristaraich",
		"steiermark"
	],
	"AMAZON.Athlete": [
		"michael johnson",
		"michael phelps",
		"kobe bryant",
		"roger federer"
	],
	"AMAZON.Author": [
		"E.L. James",
		"Stephen King",
		"Mark Twain",
		"William Shakespeare",
		"Shakespeare",
		"Nora Roberts"
	],
	"AMAZON.Book": [
		"gone girl",
		"harry potter",
		"the old man and the sea",
		"the giver",
		"the little prince",
		"nineteen eighty-four",
		"lord of the rings",
		"the kite runner",
		"slaughterhouse-five"
	],
	"AMAZON.BookSeries": [
		"harry potter",
		"silence of the lambs"
	],
	"AMAZON.BroadcastChannel": [
		"colorado public radio",
		"king fm",
		"the nineties on nine business",
		"praise",
		"radio scilly",
		"capital nine hundred fifty eight f. m.",
		"k. e. x. p."
	],
	"AMAZON.City": [
		"Chicago",
		"Los Angeles",
		"Seattle",
		"New York",
		"Cambridge",
		"Versailles",
		"Dayton",
		"Tokyo",
		"Reykjavik",
		"Pittsburgh"
	],
	"AMAZON.CivicStructure": [
		"smithsonian institute",
		"greyhound bus station",
		"museum of modern art",
		"yellowstone national park",
		"massachusetts general hospital"
	],
	"AMAZON.Color": [
		"red",
		"blue",
		"yellow",
		"black",
		"white",
		"International Klein Blue",
		"dusky pink",
		"chartreuse",
		"gunmetal",
		"orchid"
	],
	"AMAZON.Comic": [
		"justice league",
		"the amazing spiderman",
		"x-men",
		"runaways",
		"watchmen"
	],
	"AMAZON.Corporation": [
		"Amazon",
		"Facebook",
		"HP",
		"Tesla",
		"Lululemon Athletica",
		"Toyota",
		"General Electric",
		"American Express",
		"Johnson & Johnson",
		"Unilever"
	],
	"AMAZON.Country": [
		"United States",
		"Germany",
		"UK",
		"Mauritius",
		"Uruguay",
		"Japan",
		"Scotland",
		"Sri Lanka",
		"Cameroon",
		"South Korea"
	],
	"AMAZON.CreativeWorkType": [
		"magazine",
		"song",
		"book",
		"soundtrack",
		"album",
		"rap",
		"sonnet",
		"thesis",
		"novella",
		"graffiti"
	],
	"AMAZON.DayOfWeek": [
		"monday",
		"tuesday",
		"wednesday",
		"weekend",
		"weekdays"
	],
	"AMAZON.DE_CITY": [
		"berlin wilmersdorf",
		"reinheim"
	],
	"AMAZON.DE_FIRST_NAME": [
		"annika",
		"jens",
		"finn"
	],
	"AMAZON.DE_REGION": [
		"freistaat bayern",
		"rheinland pfalz"
	],
	"AMAZON.Dessert": [
		"pavlova",
		"frozen yogurt",
		"chocolate brownie",
		"red velvet cake",
		"chocolate ice cream"
	],
	"AMAZON.DeviceType": [
		"TV",
		"laptop",
		"stereo",
		"kindle",
		"echo dot",
		"kindle fire",
		"fire t. v."
	],
	"AMAZON.Director": [
		"spike lee",
		"alfred hitchcock",
		"martin scorsese",
		"jane campion",
		"ang lee"
	],
	"AMAZON.Drink": [
		"apple cider",
		"chartreuse",
		"coke",
		"espresso",
		"martini",
		"old-fashioned"
	],
	"AMAZON.EducationalOrganization": [
		"springfield high school",
		"yale",
		"juilliard school",
		"university of york",
		"washington middle school"
	],
	"AMAZON.EUROPE_CITY": [
		"loures",
		"kempten"
	],
	"AMAZON.EventType": [
		"game",
		"networking event",
		"holiday",
		"party",
		"time off",
		"meetup",
		"coffee meetup"
	],
	"AMAZON.Festival": [
		"south by southwest",
		"seattle international film festival",
		"2013 comic con international",
		"montreux jazz festival",
		"sundance film festival"
	],
	"AMAZON.FictionalCharacter": [
		"batman",
		"captain america",
		"harley quinn",
		"doctor who"
	],
	"AMAZON.FinancialService": [
		"bank of america",
		"central carolina bank and trust",
		"umpqua bank",
		"san francisco federal credit union",
		"standard life",
		"continental mortgage"
	],
	"AMAZON.FirstName": [
		"John",
		"Jack",
		"Oliver",
		"Samuel",
		"Bruce",
		"Sophie",
		"Danielle",
		"Emily",
		"Sheila",
		"Cassandra"
	],
	"AMAZON.Food": [
		"chocolate cake",
		"chow mein",
		"romano cheese",
		"bacon",
		"lemon juice",
		"scrambled egg",
		"campbell's low sodium chicken broth"
	],
	"AMAZON.FoodEstablishment": [
		"antonio's italian pizzeria",
		"ted's burgers",
		"i55 truck stop restaurant",
		"skipper's dockside",
		"taco time"
	],
	"AMAZON.Game": [
		"halo",
		"would you rather",
		"grand theft auto 5",
		"angry birds",
		"cricket quiz",
		"20 questions"
	],
	"AMAZON.GB_CITY": [
		"rhymney",
		"liverpool"
	],
	"AMAZON.GB_FIRST_NAME": [
		"stephen",
		"john"
	],
	"AMAZON.GB_REGION": [
		"scotland",
		"midlands west",
		"west midlands"
	],
	"AMAZON.Genre": [
		"Jazz",
		"Fantasy",
		"Hard rock",
		"Mystery",
		"Horror",
		"Techno",
		"Doom metal",
		"Cyberpunk",
		"Visual kei",
		"Romance"
	],
	"AMAZON.Landform": [
		"mount everest",
		"amazon",
		"devil's peak",
		"east bay",
		"half dome"
	],
	"AMAZON.LandmarksOrHistoricalBuildings": [
		"vietnam war memorial",
		"holy trinity church",
		"lds temple square",
		"madison square",
		"nevada state capitol building"
	],
	"AMAZON.Language": [
		"English",
		"French",
		"Spanish",
		"Mandarin",
		"Cantonese",
		"Punjabi",
		"Tagalog",
		"Arabic",
		"German",
		"Italian"
	],
	"AMAZON.LocalBusiness": [
		"starbucks",
		"rose nails salon",
		"goodwill",
		"disneyland",
		"jiffy lube"
	],
	"AMAZON.LocalBusinessType": [
		"men's clothing stores",
		"delis",
		"medical clinics",
		"food store",
		"auto rental store",
		"dry cleaning"
	],
	"AMAZON.MedicalOrganization": [
		"pro vet",
		"fullerton vision center",
		"children's speech therapy center",
		"diamond bar veterinary clinic",
		"fallbrook women's health center"
	],
	"AMAZON.Month": [
		"april",
		"august",
		"may",
		"october",
		"march",
		"december",
		"july",
		"september"
	],
	"AMAZON.Movie": [
		"Wonder Woman",
		"Star Wars: The Last Jedi",
		"Citizen Kane",
		"The Incredibles 2",
		"Mad Max: Fury Road",
		"The Shape of Water",
		"Avengers: Infinity War",
		"Casablanca",
		"North by Northwest",
		"Blade Runner: The Final Cut"
	],
	"AMAZON.MovieSeries": [
		"alien",
		"star wars",
		"terminator",
		"paranormal activity",
		"rocky"
	],
	"AMAZON.MovieTheater": [
		"premier theater rocky mount",
		"picture house",
		"cinemark movies ten",
		"skye cinema",
		"liberty theater dayton",
		"cinergy cinemas corsicana",
		"odeon hatfield",
		"clearlake stadium cinema"
	],
	"AMAZON.MusicAlbum": [
		"the white album",
		"thriller",
		"joshua tree",
		"nineteen eighty nine",
		"darkness on the edge of town"
	],
	"AMAZON.MusicCreativeWorkType": [
		"videos",
		"single",
		"album",
		"music albums",
		"albums",
		"track",
		"music video",
		"tune"
	],
	"AMAZON.MusicEvent": [
		"mississippi river festival",
		"thunderdome",
		"broken music tour",
		"warped tour",
		"coachella valley music and arts festival big day out"
	],
	"AMAZON.MusicGroup": [
		"coldplay",
		"drake",
		"the beatles",
		"beyonce",
		"led zeppelin"
	],
	"AMAZON.Musician": [
		"johnny cash",
		"madonna",
		"carlos santana",
		"chris martin",
		"michael jackson",
		"beyonce"
	],
	"AMAZON.MusicPlaylist": [
		"relaxing sounds",
		"dance",
		"classic rock",
		"sunday morning",
		"road trip",
		"work out",
		"bachelorette party",
		"evening",
		"classical light"
	],
	"AMAZON.MusicRecording": [
		"smells like teen spirit",
		"yesterday",
		"rolling in the deep",
		"single ladies",
		"paint it black"
	],
	"AMAZON.MusicVenue": [
		"lighthouse on the creek",
		"jack's joint",
		"mohegan sun arena",
		"susquehanna bank center",
		"kentucky opry"
	],
	"AMAZON.MusicVideo": [
		"one more time",
		"stronger",
		"somebody told me",
		"round here",
		"shake it off"
	],
	"AMAZON.Organization": [
		"university of saint francis",
		"tacobell",
		"amazon",
		"microsoft",
		"monroe bank and trust",
		"thatcher high school"
	],
	"AMAZON.Person": [
		"Barack Obama",
		"Derek Jeter",
		"Albert Einstein",
		"Mark Twain",
		"Oprah Winfrey",
		"Batman"
	],
	"AMAZON.PostalAddress": [
		"705 a ave",
		"1146 front st.",
		"10550 n. la canada",
		"1828 newton st.",
		"12 fisher ave",
		"14840 telegraph rd",
		"2 akita dr."
	],
	"AMAZON.Professional": [
		"james rice",
		"bill gates",
		"michael jordan",
		"isaac tichenor",
		"stephen king"
	],
	"AMAZON.ProfessionalType": [
		"banker",
		"architect",
		"drummer",
		"producer",
		"researcher",
		"pilot",
		"musician",
		"lawyer"
	],
	"AMAZON.RadioChannel": [
		"LBC",
		"Radio One",
		"Heart",
		"Capital FM",
		"XFM",
		"Absolute Radio",
		"Magic one thousand fifty four f.m.",
		"Classic FM",
		"Kiss",
		"Virgin Radio",
		"Jazz FM",
		"TalkSPORT"
	],
	"AMAZON.Region": [
		"Washington DC",
		"California",
		"Massachusetts",
		"United States Virgin Islands",
		"Rockies",
		"Middle East",
		"Central Africa",
		"Pampas",
		"The Highlands",
		"Cornwall"
	],
	"AMAZON.RelativePosition": [
		"top",
		"last",
		"left",
		"middle"
	],
	"AMAZON.Residence": [
		"claremont",
		"newport restoration foundation",
		"wightwick manor",
		"seth french house",
		"moore house",
		"burntwood hall",
		"arlington",
		"leinster house"
	],
	"AMAZON.Room": [
		"bathroom",
		"cellar",
		"hall",
		"laundry room",
		"lobby",
		"nursery"
	],
	"AMAZON.ScreeningEvent": [
		"object 168 film project",
		"pantalla de crystal film festival",
		"oldenburg international film festival",
		"oxford international film festival",
		"hollywood film festival",
		"the dam short film festival"
	],
	"AMAZON.Service": [
		"fresh julienne wedding and event catering",
		"coastal culinary personal chef service",
		"santa barbara private chef mattias blom",
		"notary public 411",
		"the omelet",
		"wilcox and fetzer",
		"creative touch catering"
	],
	"AMAZON.SocialMediaPlatform": [
		"delicious",
		"digg",
		"you tube",
		"blogger",
		"what's app",
		"yelp",
		"facebook"
	],
	"AMAZON.SoftwareApplication": [
		"pokemon go",
		"angry birds",
		"box of cats",
		"tinder",
		"windows",
		"office"
	],
	"AMAZON.SoftwareGame": [
		"sci-fi trivia",
		"magic eightball",
		"akinator",
		"the wayne investigation"
	],
	"AMAZON.Sport": [
		"basketball",
		"football",
		"college football",
		"team handball",
		"strength athletics",
		"snowboarding"
	],
	"AMAZON.SportsEvent": [
		"1990 fifa world cup",
		"senior women race",
		"men's 3m. springboard",
		"squash at the 2014 commonwealth games"
	],
	"AMAZON.SportsTeam": [
		"bruins",
		"patriots",
		"red bulls",
		"red sox"
	],
	"AMAZON.StreetAddress": [
		"ward pound ridge reservation",
		"pestana dr.",
		"west huron street",
		"town center s.",
		"north campbell road",
		"valley side dr. ne",
		"cochran",
		"yolanda dr."
	],
	"AMAZON.StreetName": [
		"Main Street",
		"Main St",
		"Church Street",
		"Pine Street",
		"Elm Street",
		"Oak Street",
		"Maple Street",
		"High Street",
		"River Road",
		"Walnut Street"
	],
	"AMAZON.TelevisionChannel": [
		"abc",
		"nbc",
		"cnn",
		"cartoon network",
		"espn 2"
	],
	"AMAZON.TVEpisode": [
		"jaynestown",
		"our mrs reynolds",
		"the one with the monkey",
		"lisa's wedding",
		"victor echo november"
	],
	"AMAZON.TVSeason": [
		"big brother 3 us",
		"amazing race 2",
		"saturday night live",
		"the bachelor rome"
	],
	"AMAZON.TVSeries": [
		"Seinfeld",
		"Curb Your Enthusiasm",
		"I Love Lucy",
		"The Mary Tyler Moore Show",
		"SNL",
		"Lost"
	],
	"AMAZON.US_CITY": [
		"seattle",
		"new york",
		"n.y.c."
	],
	"AMAZON.US_FIRST_NAME": [
		"john",
		"eric",
		"steve",
		"stephen",
		"annie"
	],
	"AMAZON.US_STATE": [
		"alabama",
		"alaska",
		"illinois",
		"W.A.",
		"i.l.",
		"guam",
		"district of columbia"
	],
	"AMAZON.VideoGame": [
		"doom two",
		"resident evil code veronica",
		"worms",
		"lemmings",
		"the sims"
	],
	"AMAZON.VisualModeTrigger": [
		"show",
		"view"
	],
	"AMAZON.WeatherCondition": [
		"snowfall",
		"lightning",
		"thunderstorms",
		"rain",
		"blizzard",
		"humid",
		"cold",
		"flash flood"
	],
	"AMAZON.WrittenCreativeWorkType": [
		"plays",
		"novel",
		"journal",
		"books",
		"fiction",
		"non fiction",
		"journals",
		"poems"
	]
},
	"fr-ca": {
	"AMAZON.Actor": [
		"Patrick Huard",
		"Marc-André Grondin",
		"Antoine Bertrand",
		"Anne Dorval",
		"Mélissa Désormeaux-Poulin",
		"Caroline Dhavernas",
		"Gary Oldman",
		"Frances McDormand",
		"Luc Picard",
		"Guylaine Tremblay"
	],
	"AMAZON.Airline": [
		"Air Canada",
		"Air Transat",
		"United Airlines",
		"Air France",
		"Lufthansa",
		"Qatar Airways",
		"Westjet Airlines",
		"Singapore Airways",
		"Sunwing Airways",
		"KLM"
	],
	"AMAZON.Airport": [
		"Aéroport international Jean-Lesage de Québec",
		"Aéroport international Pierre-Elliott-Trudeau de Montréal",
		"aéroport international Pearson de Toronto",
		"aéroport international de Vancouver",
		"aéroport international Macdonald-Cartier d'Ottawa",
		"aéroport international Hartsfield-Jackson d'Atlanta",
		"Aéroport international de Pékin-Capitale",
		"aéroport international de Dubaï",
		"aéroport international de Tokyo-Haneda",
		"aéroport international de Los Angeles"
	],
	"AMAZON.Animal": [
		"chien",
		"Requin-citron",
		"cheval",
		"Panthère des neiges",
		"Ours",
		"Poisson-zèbre",
		"Saumon",
		"serpent",
		"Éléphant",
		"baleine"
	],
	"AMAZON.Artist": [
		"Paul-Émile Borduas",
		"Françoise Sullivan",
		"André Mathieu",
		"Roy Dupuis",
		"Michel Tremblay",
		"U2",
		"Elvis Presley",
		"Noir Silence",
		"The Beatles",
		"Sia"
	],
	"AMAZON.Book": [
		"Savoureuses expressions québécoises",
		"Dictionnaire des intellectuel.les au Québec",
		"Maria Chapdelaine",
		"Les belles-soeurs",
		"Auprès de moi toujours",
		"Dora Bruder",
		"The Stranger",
		"Les Misérables",
		"Madame Bovary",
		"Candide"
	],
	"AMAZON.City": [
		"Montréal",
		"Québec",
		"Laval",
		"Gatineau",
		"Longueuil",
		"Tokyo",
		"Delhi",
		"Shanghai",
		"Mumbai",
		"Sao Paulo"
	],
	"AMAZON.Color": [
		"Rouge",
		"Bleu",
		"Vert",
		"Noir",
		"Gris",
		"Violet",
		"Jaune",
		"Beige",
		"Brun",
		"Blanc"
	],
	"AMAZON.Corporation": [
		"Cirque du Soleil",
		"Saputo",
		"Facebook",
		"Microsoft",
		"Berkshire Hathaway",
		"McKesson",
		"banque nationale du canada",
		"Molson",
		"Amazon.com",
		"ExxonMobil"
	],
	"AMAZON.Country": [
		"Canada",
		"États-Unis",
		"Mexique",
		"Allemagne",
		"Japon",
		"Royaume-Uni",
		"France",
		"Chine",
		"Inde",
		"Indonésie"
	],
	"AMAZON.CreativeWorkType": [
		"Opéra",
		"Spectacle de Cirque",
		"Théâtre",
		"Slam",
		"Comédie musicale",
		"Spectacle de cabaret",
		"Ballet",
		"Chanson",
		"Poème",
		"Magie"
	],
	"AMAZON.DayOfWeek": [
		"Lundi",
		"Mardi",
		"Mercredi",
		"Jeudi",
		"Vendredi",
		"Samedi",
		"Dimanche"
	],
	"AMAZON.FictionalCharacter": [
		"Harry Potter",
		"Gandalf",
		"Meredith Grey",
		"Olivia Pope",
		"Ross Geller",
		"Mickey Mouse",
		"Sherlock Holmes",
		"Pan",
		"Mario",
		"Peter Pan"
	],
	"AMAZON.FirstName": [
		"Emma",
		"Léa",
		"Alice",
		"Olivia",
		"Florence",
		"William",
		"Logan",
		"Liam",
		"Noah",
		"Jacob"
	],
	"AMAZON.Genre": [
		"Classique",
		"Rock",
		"Alternative",
		"Policier",
		"Fantastique",
		"Documentaire",
		"Nouvelles",
		"Sports",
		"Drame",
		"Animation"
	],
	"AMAZON.Language": [
		"Anglais",
		"Français",
		"Espagnol",
		"Allemand",
		"Mandarin",
		"Hindi",
		"Russe",
		"Bengali",
		"Portugais",
		"Italien"
	],
	"AMAZON.Month": [
		"Janvier",
		"Février",
		"Mars",
		"Avril",
		"Mai",
		"Juin",
		"Juillet",
		"Août",
		"Septembre",
		"Octobre",
		"Novembre",
		"Décembre"
	],
	"AMAZON.Movie": [
		"Bon Cop, Bad Cop",
		"De père en flic",
		"Avatar",
		"Harry Potter à l'école des sorciers",
		"Hannibal",
		"Titanic",
		"Le Seigneur des anneaux: La communauté de l'anneau",
		"The Holiday",
		"La femme en rouge",
		"Le Voyage"
	],
	"AMAZON.MusicAlbum": [
		"Divide",
		"Beautiful Trauma",
		"Hardwired… to Self-Destruct",
		"Everything now",
		"L'Heptade",
		"L'intégrale",
		"D'eux",
		"Immortellement célèbre",
		"Dans la peau",
		"Thriller"
	],
	"AMAZON.MusicGroup": [
		"Elvis Presley",
		"Mina",
		"Taxi Girl",
		"Superbus",
		"Les Avions",
		"Les Fatals Picards",
		"Lilicub",
		"Yelle",
		"Frank Sinatra",
		"The Beatles"
	],
	"AMAZON.Musician": [
		"Celine Dion",
		"Neil Young",
		"Sarah McLachlan",
		"Leonard Cohen",
		"Justin Bieber",
		"Avril Lavigne",
		"Alanis Morissette",
		"Shania Twain",
		"Joni Mitchell",
		"Paul Anka"
	],
	"AMAZON.MusicRecording": [
		"Solo",
		"Mercy",
		"Mon pays",
		"Donne-Moi Ma Chance",
		"House of the Rising Sun",
		"Hallelujah",
		"Je te promets",
		"Elle m'a dit",
		"Shape of you",
		"Hello"
	],
	"AMAZON.Person": [
		"Pierre Lambert",
		"Maurice Duplessis",
		"René Lévesque",
		"Pauline Marois",
		"Barack Obama",
		"Charles de Gaulle",
		"Céline Dion",
		"Justin Bieber",
		"Keanu Reeves",
		"Louis XVI"
	],
	"AMAZON.RadioChannel": [
		"BBC World Service",
		"Kiss FM",
		"energie",
		"cbc radio",
		"rouge fm",
		"rythme fm",
		"siriusxm hits",
		"CJMF-FM",
		"Cfgl-fm",
		"Ckbe-fm"
	],
	"AMAZON.Region": [
		"Ontario",
		"Colombie-Britannique",
		"Nouvelle-Écosse",
		"Québec",
		"Charlevoix",
		"Gaspé",
		"L'Assomption",
		"Abitibi",
		"Centre du Canada",
		"Maritimes"
	],
	"AMAZON.Room": [
		"Cuisine",
		"Salon",
		"chambre à coucher",
		"Salle à manger",
		"entrée",
		"Salle de bains",
		"salle de séjour",
		"Bureau",
		"Grenier",
		"Garage"
	],
	"AMAZON.Sport": [
		"Soccer",
		"Hockey",
		"Football",
		"Basketball",
		"Baseball",
		"Course",
		"Tennis",
		"Cyclisme",
		"Ski alpin",
		"Natation"
	],
	"AMAZON.StreetName": [
		"Boulevard Gouin",
		"Rue Sussex",
		"Avenue du Portage",
		"Avenue Robson",
		"Avenue Yonge Crescent",
		"Rue Saint-Paul",
		"Boulevard Grande-Allée",
		"Avenue du Parc",
		"Rue King"
	],
	"AMAZON.TVSeries": [
		"les bougon",
		"minuit, le soir",
		"passe-partout",
		"la petite vie",
		"virginie",
		"fortier",
		"la voix",
		"Narcos",
		"Les Experts",
		"Bref"
	],
	"AMAZON.VideoGame": [
		"A Way Out",
		"Assassin's Creed Odyssey",
		"Fortnite Battle Royale",
		"Angry Birds",
		"Tetris",
		"Yakuza Zero",
		"Tom Clancy's Rainbow Six: Siege",
		"Overwatch",
		"Call of Duty: Black Ops 4",
		"Clash of Clans"
	]
},
	"fr-fr": {
	"AMAZON.Actor": [
		"Jean-Paul Belmondo",
		"Dany Boon",
		"Gérard Depardieu",
		"Marion Cotillard",
		"Isabelle Huppert",
		"Jean Dujardin",
		"Jean Reno",
		"Vincent Cassel",
		"Alain Delon",
		"Louis de Funès",
		"Arletty",
		"Josiane Balasko",
		"Isabelle Adjani",
		"Juliette Binoche"
	],
	"AMAZON.Airline": [
		"Air France",
		"Icelandair",
		"Lufthansa",
		"Hop",
		"Transavia",
		"KLM",
		"Qatar Airways",
		"British Airways",
		"Ryanair",
		"XL Airways"
	],
	"AMAZON.Airport": [
		"aéroport Paris-Charles-de-Gaulle",
		"aéroport de Paris-Orly",
		"aéroport Paris-Le Bourget",
		"aéroport Lyon-Saint-Exupéry",
		"aéroport de Marseille Provence",
		"aéroport international John-F.-Kennedy de New York",
		"aéroport de Londres Heathrow",
		"aéroport international de Hong Kong",
		"aéroport international de Los Angeles",
		"aéroport international de Tokyo-Haneda"
	],
	"AMAZON.Animal": [
		"âne",
		"boa",
		"cachalot",
		"écureuil",
		"éléphant",
		"grenouille",
		"kangourou",
		"lapin",
		"méduse",
		"ornithorynque",
		"poulpe",
		"poisson",
		"rhinocéros",
		"singe",
		"sanglier"
	],
	"AMAZON.Artist": [
		"Serge Gainsbourg",
		"Edith Piaf",
		"Hector Guimard",
		"Auguste Perret",
		"Henri Cartier-Bresson",
		"Edgar Degas",
		"Henri Matisse",
		"Henri de Toulouse-Lautrec",
		"Claude Monet",
		"Pablo Picasso"
	],
	"AMAZON.Book": [
		"Les Misérables",
		"Du côté de chez Swann",
		"Madame Bovary",
		"Le Rouge et le Noir",
		"Une saison en enfer",
		"Tintin au Tibet",
		"Astérix le Gaulois",
		"Cent ans de solitude",
		"Cinquante nuances de Grey",
		"Mange, Prie, Aime",
		"Le Soleil des Scorta",
		"Petit traité de manipulation à l'usage des honnêtes gens",
		"Les Boulevards de ceinture",
		"L'Ordre du jour"
	],
	"AMAZON.City": [
		"Paris",
		"Marseille",
		"Lyon",
		"Toulouse",
		"Nice",
		"Nantes",
		"Strasbourg",
		"Montpellier",
		"Bordeaux",
		"Lille",
		"Rennes",
		"Reims",
		"Le Havre",
		"Saint-Étienne",
		"Toulon"
	],
	"AMAZON.Color": [
		"bleu",
		"blanc",
		"rouge",
		"jaune",
		"magenta",
		"cyan",
		"écarlate",
		"mauve",
		"pourpre",
		"rose",
		"orange",
		"émeraude",
		"marron",
		"argent",
		"bordeaux"
	],
	"AMAZON.Corporation": [
		"Decathlon",
		"Fnac",
		"Darty",
		"Boulanger",
		"Airbus",
		"Accor Hotels",
		"Atos",
		"Axa",
		"Danone",
		"L'Oréal",
		"Pernod Ricard"
	],
	"AMAZON.Country": [
		"Royaume-Uni",
		"Arabie Saoudite",
		"Soudan du Sud",
		"Sud-Soudan",
		"Kosovo",
		"République Démocratique du Congo",
		"R. D. C.",
		"Union Soviétique",
		"U. R. S. S.",
		"Émirats Arabes Unis",
		"E. A. U.",
		"Birmanie",
		"Myanmar",
		"Koweït",
		"El Salvador"
	],
	"AMAZON.CreativeWorkType": [
		"chanson",
		"poème",
		"livre",
		"spectacle",
		"pièce de théatre",
		"film",
		"album",
		"magazine",
		"dessin",
		"peinture"
	],
	"AMAZON.DayOfWeek": [
		"Lundi",
		"Mardi",
		"Mercredi",
		"Jeudi",
		"Vendredi",
		"Samedi",
		"Dimanche"
	],
	"AMAZON.FictionalCharacter": [
		"Robin des Bois",
		"Robinson Crusoé",
		"Arsène Lupin",
		"Gandalf",
		"Astérix",
		"Mickey Mouse",
		"Sherlock Holmes",
		"Albus Dumbledore",
		"Pan",
		"Mario"
	],
	"AMAZON.FirstName": [
		"Julien",
		"Thomas",
		"Nicolas",
		"Alexandre",
		"Jean-Baptiste",
		"Nathalie",
		"Camille",
		"Pauline",
		"Julie",
		"Anne-Sophie",
		"Karim",
		"Malika",
		"Gwenael",
		"Enzo"
	],
	"AMAZON.Food": [
		"crêpes",
		"boeuf bourguignon",
		"ratatouille",
		"pot-au-feu",
		"clafoutis",
		"hachis parmentier",
		"gigot d'agneau",
		"tarte Tatin",
		"profiteroles",
		"canelés",
		"tapenade",
		"Boeuf Strogonoff",
		"bortsch",
		"aïoli",
		"gougères"
	],
	"AMAZON.Genre": [
		"Jazz",
		"Alternatif",
		"Classique",
		"Science-Fiction",
		"Drame",
		"Polar",
		"Romantique",
		"Horreur",
		"Action"
	],
	"AMAZON.Language": [
		"mandarin",
		"arabe",
		"chinois",
		"hindi",
		"bulgare",
		"tchèque",
		"danois",
		"allemand",
		"estonien",
		"grec",
		"anglais",
		"espagnol",
		"français",
		"irlandais",
		"croate",
		"italien",
		"letton",
		"lituanien",
		"hongrois",
		"maltais",
		"néerlandais",
		"polonais",
		"portugais",
		"roumain",
		"slovaque",
		"slovène",
		"finnois",
		"suédois"
	],
	"AMAZON.Month": [
		"Janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"AMAZON.Movie": [
		"La Grande Vadrouille",
		"Les Tontons flingueurs",
		"Vol au-dessus d'un nid de coucou",
		"Le Fabuleux Destin d'Amélie Poulain",
		"Intouchables",
		"Astérix et Obélix : Mission Cléopâtre",
		"Le Bon, la brute et le truand",
		"Bienvenue chez les Ch'tis",
		"La Cité de la peur",
		"Léon",
		"Le Seigneur des anneaux : la communauté de l'anneau",
		"Les nouveaux sauvages",
		"120 battements par minute",
		"Au revoir là-haut",
		"Le Sens de la fête"
	],
	"AMAZON.MusicAlbum": [
		"Crache ton venin",
		"Paris sous les bombes",
		"L'école du micro d'argent",
		"L'Everest",
		"Les Vieilles Canailles",
		"Encore un soir",
		"Racine carrée",
		"5 minutes au paradis",
		"Blitz",
		"Viens je t'emmène",
		"A nos amours",
		"Presence"
	],
	"AMAZON.MusicGroup": [
		"Daft Punk",
		"IAM",
		"NTM",
		"PNL",
		"Bisso Na Bisso",
		"Téléphone",
		"Têtes raides",
		"Les Musclés",
		"Fréro Delavega",
		"David et Jonathan",
		"Birdy Nam Nam",
		"Gotan Project",
		"Phoenix",
		"Sexy Sushi",
		"Les Fatals Picards",
		"Chico and the Gypsies",
		"L'Affaire Louis'Trio",
		"Les Rita Mitsouko",
		"Magic System"
	],
	"AMAZON.Musician": [
		"Mathias Duplessy",
		"Kungs",
		"Claude Debussy",
		"Johnny Hallyday",
		"Jean-Philippe Rameau",
		"François Couperin",
		"Jean-Baptiste Lully",
		"Hector Berlioz",
		"Maurice Ravel",
		"Jacques Offenbach",
		"Serge Gainsbourg",
		"Charles Aznavour",
		"Edith Piaf",
		"Georges Bizet",
		"Camille Saint-Saëns",
		"Paul Dukas",
		"Charles Gounod",
		"Gabriel Fauré",
		"Francis Cabrel",
		"David Guetta",
		"Georges Brassens",
		"Claude François",
		"Renaud"
	],
	"AMAZON.MusicRecording": [
		"Je danse le mia",
		"Nés sous la même étoile",
		"Non, je ne regrette rien",
		"La Vie En Rose",
		"Padam, padam",
		"Je te promets",
		"Que je t'aime",
		"L'Envie",
		"Ella, elle l'a",
		"Viens je t'emmène",
		"L'aigle noir",
		"La dernière séance",
		"Sur la route de Memphis",
		"Dernière danse",
		"Tourner dans le vide",
		"Formidable",
		"Allumer le feu"
	],
	"AMAZON.Person": [
		"Emmanuel Macron",
		"Brigitte Macron",
		"François Fillon",
		"Zinédine Zidane",
		"Johnny Hallyday",
		"Serge Gainsbourg",
		"Xavier Niel",
		"Marcel Proust",
		"Louis XVI",
		"Marianne",
		"Astérix",
		"Jean Paul Gaultier",
		"Charles de Gaulle",
		"Napoléon Ier"
	],
	"AMAZON.RadioChannel": [
		"fip",
		"bfm",
		"nrj",
		"rfi romania",
		"bbc world service",
		"france musique",
		"tsf jazz",
		"Oüi Fm",
		"rtl",
		"france bleu"
	],
	"AMAZON.Region": [
		"Auvergne-Rhône-Alpes",
		"Bourgogne-Franche-Comté",
		"Bretagne",
		"Centre-Val de Loire",
		"Corse",
		"Grand Est",
		"Hauts-de-France",
		"Île-de-France",
		"Normandie",
		"Nouvelle-Aquitaine",
		"Occitanie",
		"Pays de la Loire",
		"Provence-Alpes-Côte d'Azur",
		"PACA",
		"Guadeloupe",
		"Martinique"
	],
	"AMAZON.Room": [
		"entrée",
		"séjour",
		"chambre",
		"chambre des enfants",
		"chambre des parents",
		"dortoir",
		"couloir",
		"cave",
		"salle de bain",
		"salle à manger",
		"jardin",
		"terrasse",
		"balcon",
		"bureau",
		"salle d'attente",
		"accueil"
	],
	"AMAZON.Sport": [
		"Foot",
		"tennis",
		"rugby",
		"golf",
		"natation",
		"athlétisme",
		"basket",
		"hockey",
		"judo",
		"handball"
	],
	"AMAZON.StreetName": [
		"Place de l'Église",
		"Grande Rue",
		"Rond-Point des Champs-Élysées Marcel-Dassault",
		"Rue de la Fontaine",
		"Place de la Mairie",
		"Rue du Moulin",
		"Rue des Écoles",
		"Rue de la Gare",
		"Rue Pasteur",
		"Rue Victor-Hugo",
		"Rue du Quatorze-Juillet",
		"Avenue de l'Opéra",
		"Quai des Orfèvres",
		"Impasse de la Baleine",
		"Parvis de la Défense"
	],
	"AMAZON.TVSeries": [
		"Les feux de l'amour",
		"Plus belle la vie",
		"Le bureau des légendes",
		"Les revenants",
		"Braquo",
		"Versailles",
		"Borgia",
		"Baron Noir",
		"Kaboul Kitchen",
		"Jour Polaire",
		"Les Experts",
		"24 heures chrono",
		"Narcos",
		"Les Shadoks",
		"Bref"
	],
	"AMAZON.VideoGame": [
		"Destiny",
		"Star Wars Battlefront",
		"Les Sims",
		"Syberia",
		"God of War",
		"Dishonored",
		"Assassin's Creed",
		"Mario + The Lapins Crétins Kingdom Battle",
		"Uncharted: Drake's Fortune",
		"FIFA 18",
		"The Last of Us"
	]
},
	"de-de": {
	"AMAZON.Actor": [
		"Emma Watson",
		"Rupert Grint",
		"Steven Seagal",
		"David Bowie",
		"Russell Crowe",
		"Tom Hanks",
		"Daniel Radcliffe"
	],
	"AMAZON.Airline": [
		"Lufthansa",
		"Eurowings",
		"easyJet",
		"Ryanair",
		"Turkish Airlines",
		"Condor",
		"KLM",
		"Delta Air Lines",
		"Emirates",
		"British Airways"
	],
	"AMAZON.Airport": [
		"Flughafen Frankfurt am Main",
		"Flughafen Berlin-Tegel",
		"Flughafen Berlin Brandenburg",
		"Flughafen München",
		"Flughafen Düsseldorf",
		"Flughafen London Heathrow",
		"Flughafen Paris-Charles-de-Gaulle",
		"Flughafen Schiphol",
		"Flughafen Peking",
		"Flughafen Dubai"
	],
	"AMAZON.Animal": [
		"Hund",
		"Katze",
		"Meerschweinchen",
		"Hamster",
		"Kanarienvogel",
		"Hase",
		"Pferd",
		"Rind",
		"Kleintiere",
		"Schwein",
		"Huhn",
		"Löwe",
		"Zebra",
		"Ziervögel",
		"Giraffe",
		"Koala",
		"Strauß",
		"Schäferhund",
		"Dackel",
		"Reh"
	],
	"AMAZON.Artist": [
		"Pablo Picasso",
		"Claude Monet",
		"George Lucas",
		"Jennifer Lawrence",
		"Mark Knopfler",
		"Jay-Z",
		"Michael Jackson",
		"Ryan Gosling",
		"Madonna",
		"Joachim Ringelnatz",
		"Kurt Cobain",
		"Helene Fischer",
		"Lady Gaga",
		"Robbie Williams",
		"Ed Sheeran"
	],
	"AMAZON.AT_CITY": [
		"graz",
		"vienna"
	],
	"AMAZON.AT_REGION": [
		"nideristaraich",
		"steiermark"
	],
	"AMAZON.Book": [
		"1984",
		"Der Vorleser",
		"Wiedersehen im Café am Rande der Welt: Eine inspirierende Reise zum eigenen Selbst",
		"Harry Potter und der Stein der Weisen",
		"Im Westen nichts Neues",
		"Pippi Langstrumpf: Gesamtausgabe",
		"Darm mit Charme: Alles über ein unterschätztes Organ - aktualisierte Neuauflage",
		"Der Report der Magd: Roman",
		"Der Tod in Venedig. Novelle.",
		"Jane Eyre: Roman"
	],
	"AMAZON.City": [
		"Berlin",
		"Hamburg",
		"München",
		"Köln",
		"Stuttgart"
	],
	"AMAZON.Color": [
		"gold",
		"orange",
		"violett",
		"lila",
		"pink",
		"grün",
		"anthrazit",
		"hellgrau",
		"hellbraun",
		"gunkelbraun",
		"hautfarben",
		"beige",
		"hellblau",
		"dunkelblau",
		"himmelblau",
		"türkis",
		"hellgrün",
		"dunkelgrün",
		"hellrot",
		"weinrot",
		"goldgelb",
		"blutrot"
	],
	"AMAZON.Corporation": [
		"Volkswagen",
		"Audi",
		"BMW",
		"Mercedes-Benz",
		"Siemens",
		"Bosch",
		"BASF",
		"Telekom",
		"Bayer",
		"Aldi",
		"Continental",
		"Lufthansa",
		"Bertelsmann",
		"SAP",
		"Dr. Oetker"
	],
	"AMAZON.Country": [
		"Belgien",
		"Volksrepublik China",
		"Königreich Dänemark",
		"Griechenland",
		"Deutschland",
		"Frankreich",
		"Italien",
		"Nordkorea",
		"Großherzogtum Luxemburg",
		"Niederlande",
		"Österreich",
		"Russland",
		"Türkei",
		"USA",
		"Großbritanien"
	],
	"AMAZON.CreativeWorkType": [
		"Lied",
		"Gedicht",
		"Roman",
		"Theaterstück",
		"Gemälde",
		"Film",
		"Foto",
		"Oper",
		"Tanz",
		"Kurzgeschichte"
	],
	"AMAZON.DayOfWeek": [
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag",
		"Sonntag"
	],
	"AMAZON.DE_CITY": [
		"berlin wilmersdorf",
		"reinheim"
	],
	"AMAZON.DE_FIRST_NAME": [
		"annika",
		"jens",
		"finn"
	],
	"AMAZON.DE_REGION": [
		"freistaat bayern",
		"rheinland pfalz"
	],
	"AMAZON.EUROPE_CITY": [
		"loures",
		"kempten"
	],
	"AMAZON.FictionalCharacter": [
		"Harry Potter",
		"Krümelmonster",
		"James Bond",
		"Benjamin Blümchen",
		"Indiana Jones",
		"Micky Maus",
		"Sherlock Holmes",
		"Winnetou",
		"Batman",
		"Wolverine"
	],
	"AMAZON.FirstName": [
		"Marie",
		"Sophie",
		"Sophia",
		"Maria",
		"Stephanie",
		"Sophia",
		"Katharina",
		"Julia",
		"Anna",
		"Anne",
		"Sarah",
		"Hannah",
		"Christian",
		"Maximilian",
		"Alexander",
		"Daniel",
		"Phillipp",
		"Leon",
		"Lukas",
		"Stefan",
		"Markus",
		"Felix",
		"anna"
	],
	"AMAZON.Food": [
		"Gulaschsuppe",
		"Pizza",
		"Spaghetti Bolognese",
		"Sushi",
		"Wiener Schnitzel",
		"Fischstäbchen",
		"Zwiebelkuchen",
		"Kaiserschmarrn",
		"Käsekuchen",
		"Kohlrouladen",
		"Königsberger Klopse",
		"Tiramisu",
		"Götterspeise",
		"Vanillepudding",
		"Schwarzwälder Kirschtorte",
		"Bami Goreng",
		"Döner Kebap",
		"Frikadellen",
		"Kartoffelsalat",
		"Grünkohl",
		"Spargel",
		"Erdbeeren",
		"Bratwurst",
		"Sauerbraten",
		"Maultaschen",
		"Kartoffelpuffer",
		"Weißwurst",
		"Erbsensuppe",
		"Currywurst",
		"Brathering",
		"Forelle Müllerin Art",
		"Leipziger Allerlei",
		"Gyros"
	],
	"AMAZON.GB_CITY": [
		"rhymney",
		"liverpool"
	],
	"AMAZON.GB_FIRST_NAME": [
		"stephen",
		"john"
	],
	"AMAZON.GB_REGION": [
		"scotland",
		"midlands west",
		"west midlands"
	],
	"AMAZON.Genre": [
		"Science Fiction",
		"Fantasie",
		"Action",
		"Horror",
		"Drama",
		"Komödie",
		"Krimi",
		"Animation",
		"Thriller",
		"Pop",
		"Schlager",
		"Hip Hop",
		"Musical",
		"Klassik",
		"Electro"
	],
	"AMAZON.Language": [
		"englisch",
		"spanisch",
		"italienisch",
		"französisch",
		"portugiesisch"
	],
	"AMAZON.Month": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember",
		"Juno",
		"Julei"
	],
	"AMAZON.Movie": [
		"Avatar",
		"Fack ju Göhte",
		"Die Eiskönigin - Völlig unverfroren",
		"Spectre",
		"Minions",
		"Titanic",
		"Jurassic World",
		"Marvel's The Avengers",
		"Harry Potter",
		"Die Verurteilten",
		"Das Schweigen der Lämmer",
		"Fight Club",
		"Pulp Fiction",
		"Inception",
		"Der Pate",
		"Der weiße Hai",
		"Fluch der Karibik",
		"Der Herr der Ringe",
		"Findet Nemo",
		"Das Dschungelbuch",
		"Casino Royale",
		"American Pie",
		"Schindlers Liste"
	],
	"AMAZON.MusicAlbum": [
		"Mensch",
		"Farbenspiel",
		"Nevermind",
		"We can't dance",
		"Over the Hump",
		"Abenteuerland",
		"21",
		"Back to Black",
		"Backstreet's Back",
		"Rubber Soul",
		"Like a Prayer",
		"Kid A"
	],
	"AMAZON.MusicGroup": [
		"The Beatles",
		"AC/DC",
		"Pink Floyd",
		"The Rolling Stones",
		"Nirvana",
		"Bon Jovi",
		"Led Zeppelin",
		"Die Ärzte",
		"Die Toten Hosen",
		"Böhse Onkelz",
		"Rammstein",
		"Beatsteaks",
		"Linkin Park",
		"Metallica",
		"Evanescence"
	],
	"AMAZON.Musician": [
		"Udo Jürgens",
		"Udo Lindenberg",
		"André Rieu",
		"Ludwig van Beethoven",
		"Wolfgang Amadeus Mozart",
		"Django Reinhardt",
		"Florian Silbereisen",
		"Xavier Naidoo",
		"Peter Maffay",
		"Eric Clapton",
		"Elvis Presley",
		"Édith Piaf",
		"Montserrat Caballé",
		"Helene Fischer",
		"Mark Forster"
	],
	"AMAZON.MusicRecording": [
		"Love will tear us apart",
		"Smells like teen spirit",
		"Imagine",
		"Like a prayer",
		"Atemlos durch die Nacht",
		"99 Luftballons",
		"Autobahn",
		"All you need is love",
		"Knockin' on heaven's door",
		"No woman no cry",
		"Respect",
		"Lose Yourself",
		"The Ketchup Song",
		"Hey Ya!"
	],
	"AMAZON.Person": [
		"Wolfgang Amadeus Mozart",
		"Goethe",
		"Einstein",
		"Kanzlerin Merkel",
		"Angie",
		"Mutti",
		"Pink",
		"Immanuel Kant",
		"Ludwig van Beethoven",
		"Friedrich Nietzsche"
	],
	"AMAZON.RadioChannel": [
		"Antenne Bayern",
		"SWR3",
		"Hit Radio FFH",
		"BigFM",
		"BBC Radio 1",
		"KIIS-FM",
		"NDR Info",
		"WDR 2 Klassik",
		"WHTZ",
		"WIHT"
	],
	"AMAZON.Region": [
		"Niedersachsen",
		"Schleswig-Holstein",
		"Mecklenburg-Vorpommern",
		"Bayern",
		"Balearen",
		"Kanaren",
		"Toskana",
		"Andalusien",
		"Kappadokien",
		"Weserbergland",
		"Sächsische Schweiz",
		"Allgäu",
		"Schwäbische Alb",
		"Nationalpark Wattenmeer",
		"Ruhrgebiet"
	],
	"AMAZON.Room": [
		"Zimmer",
		"Küche",
		"Bad",
		"Badezimmer",
		"Schlafzimmer",
		"Esszimmer",
		"Flur",
		"Lobby",
		"Lounge",
		"Kinderzimmer",
		"Dachboden",
		"Garage",
		"Speicher",
		"Klassenzimmer",
		"Treppenhaus",
		"Arbeitszimmer",
		"Büro",
		"Keller",
		"Gästezimmer",
		"Speisekammer"
	],
	"AMAZON.Sport": [
		"Fußball",
		"Leichtathletik",
		"Boxen",
		"Skisport",
		"Motorsport",
		"Handball",
		"Schwimmen",
		"Tennis",
		"Radsport",
		"Basketball"
	],
	"AMAZON.StreetName": [
		"Marienplatz",
		"Potsdamer Platz",
		"Walther-Schreiber-Platz",
		"Hauptstraße",
		"Schulstraße",
		"Gartenstraße",
		"Bahnhofstraße",
		"Dorfstraße",
		"Bergstraße",
		"Mariahilfer Straße",
		"Kärnter Straße",
		"Landstraßer Hauptstraße",
		"Kramergasse",
		"Getreidegasse",
		"Kaiserstraße"
	],
	"AMAZON.TVSeries": [
		"Tatort",
		"Die Simpsons",
		"Unter Uns",
		"Game of Thrones",
		"The Walking Dead",
		"How I Met Your Mother",
		"The Big Bang Theory",
		"Two and a Half Men",
		"Navy CIS",
		"Criminal Minds",
		"Breaking Bad",
		"Verbotene Liebe",
		"Die Sendung mit der Maus"
	],
	"AMAZON.US_CITY": [
		"seattle",
		"new york",
		"n.y.c."
	],
	"AMAZON.US_FIRST_NAME": [
		"john",
		"eric",
		"steve",
		"stephen",
		"annie"
	],
	"AMAZON.US_STATE": [
		"alabama",
		"alaska",
		"illinois",
		"W.A.",
		"i.l.",
		"guam",
		"district of columbia"
	],
	"AMAZON.VideoGame": [
		"Pokémon GO",
		"Clash of Clans",
		"Tetris",
		"Die Sims",
		"World of Warcraft",
		"Fortnite",
		"League of Legends",
		"Grand Theft Auto V",
		"FIFA 19",
		"Monster Hunter: World"
	]
},
	"hi-in": {
	"AMAZON.City": [
		"Mumbai",
		"मुम्बई",
		"Delhi",
		"चेन्नई",
		"Bangalore",
		"कोलकाता",
		"Hyderabad",
		"पुणे",
		"Chennai",
		"अहमदाबाद"
	],
	"AMAZON.Color": [
		"लाल",
		"पीला",
		"soft blue",
		"भूरा",
		"jade",
		"गहरा बैंगनी",
		"dark violet",
		"venetian red",
		"बादल नीला",
		"gold"
	],
	"AMAZON.Country": [
		"भारत",
		"India",
		"केन्या",
		"Norway",
		"मंगोलिया",
		"Brazil",
		"बहामा",
		"Japan",
		"ताजिकिस्तान गणराज्य",
		"Cook Islands"
	],
	"AMAZON.CreativeWorkType": [
		"उपन्यास",
		"video game",
		"कहानी",
		"blog",
		"कथकली",
		"thesis",
		"रस लीला",
		"album",
		"फोटो",
		"stand-up comedy"
	],
	"AMAZON.DayOfWeek": [
		"शुक्रवार",
		"Monday",
		"बृहस्पतिवार",
		"Tuesday",
		"मंगलवार",
		"Thursday",
		"सोमवार",
		"Saturday",
		"गुरुवार",
		"Sunday"
	],
	"AMAZON.FirstName": [
		"अभिजीत",
		"Seema",
		"रजनीश",
		"Abhishek",
		"नीलम",
		"Fareed",
		"अनीश",
		"Veera",
		"संजीत",
		"Arijit"
	],
	"AMAZON.Language": [
		"हिंदी",
		"afrikaans",
		"अंग्रेज़ी",
		"italian",
		"कश्मीरी",
		"canadian french",
		"पोलिश",
		"uighur",
		"सिंहली",
		"amharic"
	],
	"AMAZON.Month": [
		"अक्टूबर",
		"January",
		"चैत्र",
		"April",
		"अश्विन",
		"July",
		"दिसंबर",
		"September",
		"नवंबर",
		"November"
	],
	"AMAZON.RadioChannel": [
		"Radio Mirchi",
		"Vividh Bharati",
		"AIR FM Rainbow",
		"Radio Mango 91.9",
		"BBC Hindi",
		"Virgin Radio",
		"Classic FM",
		"WNYC",
		"Heart 104.9 FM",
		"106.4 FM Radio Gold"
	],
	"AMAZON.Region": [
		"Bihar",
		"असम",
		"Assam",
		"आन्ध्र प्रदेश",
		"Haryana",
		"उत्तराखण्ड",
		"Jharkhand",
		"गुजरात",
		"Goa",
		"छत्तीसगढ़"
	],
	"AMAZON.Room": [
		"अध्ययन कक्ष",
		"sun room",
		"अटारी",
		"suite",
		"शयनकक्ष",
		"studio",
		"सायबान",
		"dojo",
		"पाख़ाना",
		"parlor"
	],
	"AMAZON.Sport": [
		"तैराकी",
		"Hockey",
		"कुश्ती",
		"Cricket",
		"मैराथन",
		"Rugby",
		"मुक्केबाज़ी",
		"Tennis",
		"कयाकिंग",
		"Soccer"
	],
	"AMAZON.VideoGame": [
		"Pokémon Red",
		"Minecraft",
		"Pulse Racer",
		"Ratchet and Clank",
		"Firewatch",
		"Final Fantasy VII",
		"Donkey Kong",
		"The New Tetris",
		"The Sims 2",
		"The Witcher 3: Wild Hunt"
	]
},
	"it-it": {
	"AMAZON.Actor": [
		"Roberto Benigni",
		"Christian De Sica",
		"Ornella Muti",
		"Leonardo DiCaprio",
		"Charlie Chaplin",
		"Nanni Moretti",
		"Margherita Buy",
		"Alba Rohrwacher",
		"Cate Blanchett",
		"Marlon Brando"
	],
	"AMAZON.Airline": [
		"Alitalia",
		"Ryanair",
		"Meridiana",
		"Air Dolomiti",
		"Blue Panorama Airlines",
		"Alitalia CityLiner",
		"EasyJet",
		"Lufthansa",
		"Air France",
		"Iberia"
	],
	"AMAZON.Airport": [
		"Aeroporto di Bergamo-Orio al Serio",
		"Aeroporto di Venezia-Tessera",
		"Aeroporto di Francoforte sul Meno",
		"Aeroporto di Londra-Heathrow",
		"Aeroporto di Parigi Charles de Gaulle",
		"Aeroporto di Amsterdam-Schiphol",
		"Aeroporto di Barcellona-El Prat",
		"Aeroporto di Roma-Fiumicino",
		"Aeroporto di Milano-Malpensa",
		"Aeroporto di Roma-Ciampino"
	],
	"AMAZON.Animal": [
		"Cane",
		"Cavallo",
		"Toro",
		"Leone",
		"Uccello",
		"Pinguino dai piedi neri",
		"Gatto rugginoso",
		"Moretta americana",
		"serpente",
		"pesce"
	],
	"AMAZON.Artist": [
		"Leonardo Da Vinci",
		"Amedeo Modigliani",
		"Rino Gaetano",
		"Mina",
		"Toni Servillo",
		"Monica Bellucci",
		"Alessandro Manzoni",
		"Giacomo Leopardi",
		"Italo Calvino",
		"Michelangelo Buonarroti"
	],
	"AMAZON.Book": [
		"I Promessi Sposi",
		"Quel che resta del giorno",
		"I Malavoglia",
		"Destare i morti",
		"Nel labirinto delle ombre",
		"Percy Jackson e gli dei dell'Olimpo: Il ladro di fulmini",
		"Anna Karenina",
		"Oliver Twist",
		"Violatore di blocco",
		"1984"
	],
	"AMAZON.City": [
		"Colonia",
		"Napoli",
		"Orvieto",
		"L'Aquila",
		"Padova",
		"Siviglia",
		"Salisburgo",
		"Zurigo",
		"Arezzo",
		"Siracua",
		"Udine",
		"Rimini",
		"Amburgo",
		"Forlì",
		"Bolzano"
	],
	"AMAZON.Color": [
		"Rosso",
		"Azzurro",
		"Verde",
		"Oro",
		"Vermiglione",
		"Grigio",
		"Platino",
		"Zafferano",
		"Fucsia",
		"Beige",
		"Turchese",
		"Viola",
		"Giallo",
		"Rosa"
	],
	"AMAZON.Corporation": [
		"Google",
		"General Motors",
		"SK Telecom",
		"IKEA",
		"General Electric",
		"Ebay",
		"Toyota Tsusho",
		"Yahoo!",
		"Black and Decker",
		"Fisker Inc"
	],
	"AMAZON.Country": [
		"Sierra Leone",
		"Portogallo",
		"Cina",
		"Stati Uniti d'America",
		"Giappone",
		"Nuova Zelanda",
		"Messico",
		"Grecia",
		"Giordania",
		"Giamaica",
		"Sudafrica",
		"Regno Unito",
		"Danimarca",
		"Ecuador",
		"Cambogia"
	],
	"AMAZON.CreativeWorkType": [
		"Canzone",
		"Opera",
		"Poesia",
		"Romanzo",
		"Film",
		"Dipinto",
		"Scultura",
		"Fotografia",
		"Fumetto",
		"teatro"
	],
	"AMAZON.DayOfWeek": [
		"Lunedì",
		"Sabato",
		"Giovedì",
		"Martedì",
		"Domenica",
		"Mercoledì",
		"Venerdì"
	],
	"AMAZON.FictionalCharacter": [
		"Pinocchio",
		"Gandalf",
		"Harry Potter",
		"Topolino",
		"James Bond",
		"Indiana Jones",
		"Peter Pan",
		"Superman",
		"Quasimodo",
		"Frankenstein"
	],
	"AMAZON.FirstName": [
		"Serena",
		"Gino",
		"Giorgia",
		"Michela",
		"Rita",
		"Vincenzo",
		"Aniello",
		"Giuseppe",
		"Lucrezia",
		"Fulvio",
		"Federica",
		"Maura",
		"Maurizio",
		"Jessica",
		"Miriam"
	],
	"AMAZON.Food": [
		"Pasta",
		"Farina",
		"Pomodoro",
		"Aglio",
		"Olio d'oliva",
		"Cipolla",
		"Gnocchi di patate",
		"Parmigiana",
		"Ragù di carne",
		"Polenta"
	],
	"AMAZON.Genre": [
		"Pop",
		"Rock",
		"Rap",
		"Giallo",
		"Narrativa",
		"Talk Show",
		"Reality",
		"Informazione",
		"Commedia",
		"Animazione"
	],
	"AMAZON.Language": [
		"Inglese",
		"Francese",
		"Tedesco",
		"Spagnolo",
		"Portoghese",
		"Cinese",
		"Giapponese",
		"Catalan",
		"Russo",
		"Svedese",
		"Olandese",
		"Danese",
		"Turco",
		"Polacco",
		"Norvegese",
		"Greco"
	],
	"AMAZON.Month": [
		"Gennaio",
		"Febraio",
		"Marzo",
		"Aprile",
		"Maggio",
		"Giugno",
		"Luglio",
		"Agosto",
		"Settembre",
		"Ottobre",
		"Novembre",
		"Dicembre"
	],
	"AMAZON.Movie": [
		"Il Silenzio Degli Innocenti",
		"La Dolce Vita",
		"Psyco",
		"Nuovo Cinema Paradiso",
		"Un Marito Per Cinzia",
		"Orgoglio e Passione",
		"Benvenuti al Sud",
		"Il Muro di Gomma",
		"Uccellacci e Uccellini",
		"La Vita è Bella"
	],
	"AMAZON.MusicAlbum": [
		"Fatti sentire",
		"Plume",
		"Evolve",
		"A head full of dreams",
		"Thriller",
		"Il re dell'organetto",
		"Primo Tempo",
		"Simili",
		"Fuoricampo",
		"Davide"
	],
	"AMAZON.MusicGroup": [
		"Pink Floyd",
		"Tiromancino",
		"Negramaro",
		"Elio e le Storie Tese",
		"Premiata Forneria Marconi",
		"Stadio",
		"99 Posse",
		"Almamegretta",
		"Articolo 31",
		"Banco del Mutuo Soccorso"
	],
	"AMAZON.Musician": [
		"Jovanotti",
		"Vasco Rossi",
		"Fabrizio Moro",
		"Gianna Nannini",
		"Imagine Dragons",
		"Coldplay",
		"Mina",
		"Ed Sheeran",
		"Bon Jovi",
		"Andrea Bocelli"
	],
	"AMAZON.MusicRecording": [
		"Amor Cobarde",
		"Hallelujah",
		"Luna caprese",
		"Il nostro concerto",
		"Il cielo in una stanza",
		"Thinking Out Loud",
		"Magic",
		"I Walk the Line",
		"Ma il cielo è sempre più blu",
		"What A Wonderful World"
	],
	"AMAZON.Person": [
		"Matteo Renzi",
		"Silvio Berlusconi",
		"Giuseppe Garibaldi",
		"Paolo Gentiloni",
		"Dante Alighieri",
		"Vladimir Putin",
		"Barack Obama",
		"Robert De Niro",
		"Giorgio Armani",
		"Carla Bruni"
	],
	"AMAZON.RadioChannel": [
		"RDS",
		"Radio 105",
		"Radio 24",
		"Radio cuore",
		"Radio Italia",
		"Radio Kiss Kiss Italia",
		"Radio Radicale",
		"Radio Fantastica",
		"Radio Popolare",
		"Rai Radio 1",
		"Rai Radio 2",
		"Rai Radio 3"
	],
	"AMAZON.Region": [
		"New York",
		"Calabria",
		"Campania",
		"Piemonte",
		"Valle d'Aosta",
		"Baviera",
		"Baden-Württemberg",
		"Grigioni",
		"Berna",
		"Occitania",
		"Lombardia",
		"Puglia",
		"Sardegna",
		"Sicilia",
		"Toscana"
	],
	"AMAZON.Room": [
		"Camera da Letto",
		"Soggiorno",
		"Cucina",
		"Ingresso",
		"Bagno",
		"Vestibolo",
		"Balcone",
		"Corridoio",
		"Ripostiglio",
		"Cantina",
		"Garage"
	],
	"AMAZON.Sport": [
		"Calcio",
		"Nuoto",
		"Tennis",
		"Rugby",
		"Motorsports",
		"Ciclismo",
		"Pallavolo",
		"Pallacanestro",
		"Wrestling",
		"Pattinagio"
	],
	"AMAZON.StreetName": [
		"Via Garibaldi",
		"Via Montebello",
		"Borgo Allegri",
		"Piazza San Marco",
		"Corso Europa",
		"Via Roma Viale Mazzini",
		"Corso Italia",
		"Via Savonarola",
		"Via XX Settembre",
		"Via Vittorio Emanuele",
		"Piazza Italia",
		"Piazza Centrale",
		"Via Dei Tornabuoni"
	],
	"AMAZON.TVSeries": [
		"Breaking Bad",
		"Il trono di spade",
		"I Simpson",
		"The Walking Dead",
		"Il Commissario Montalbano",
		"Friends",
		"Star Trek",
		"Crash Course",
		"Common Law",
		"The Dick Powell Show"
	],
	"AMAZON.VideoGame": [
		"La Terra di Mezzo: L'Ombra di Mordor",
		"Final Fantasy X",
		"Tekken 5",
		"Super Mario Bros.",
		"Mario Kart: Double Dash!",
		"Minecraft",
		"The Legend of Zelda: Twilight Princess",
		"Battlefield Vietnam",
		"Lo Hobbit",
		"Pokémon Rosso Fuoco"
	]
},
	"ja-jp": {
	"AMAZON.Actor": [
		"綾瀬はるか",
		"堺雅人",
		"柴咲コウ",
		"妻夫木聡",
		"福山雅治",
		"唐沢寿明",
		"大竹しのぶ",
		"黒木瞳",
		"菅田将暉",
		"渡辺謙",
		"阿部寛",
		"役所広司",
		"木村拓哉",
		"市川海老蔵",
		"高畑充希"
	],
	"AMAZON.Airline": [
		"JAL",
		"ANA",
		"バニラ・エア",
		"スカイマーク",
		"スターフライヤー",
		"ユナイテッド航空",
		"シンガポール航空",
		"デルタ航空",
		"エア・カナダ",
		"エールフランス"
	],
	"AMAZON.Airport": [
		"成田国際空港",
		"羽田空港",
		"新千歳空港",
		"中部国際空港",
		"那覇空港",
		"ロンドン・ヒースロー空港",
		"ドバイ国際空港",
		"ロサンゼルス国際空港",
		"シカゴ・ミッドウェー国際空港",
		"ジョン・F・ケネディ国際空港"
	],
	"AMAZON.Animal": [
		"犬",
		"猫",
		"パンダ",
		"うさぎ",
		"ハムスター",
		"ぞう",
		"馬",
		"タヌキ",
		"トラ",
		"イルカ",
		"キツネ",
		"リス",
		"レッサーパンダ",
		"クマ",
		"カピバラ"
	],
	"AMAZON.Artist": [
		"葛飾北斎",
		"村上隆",
		"俵屋宗達",
		"尾形光琳",
		"伊藤若冲",
		"運慶",
		"岡本太郎",
		"横山大観",
		"東郷青児",
		"竹久夢二",
		"東山魁夷",
		"棟方志功",
		"草間彌生",
		"東洲斎写楽",
		"歌川広重"
	],
	"AMAZON.Author": [
		"夏目漱石",
		"太宰治",
		"村上春樹",
		"東野圭吾",
		"宮沢賢治",
		"司馬遼太郎",
		"佐伯泰英",
		"宮部みゆき",
		"鎌池和馬",
		"湊かなえ",
		"有川浩",
		"芥川龍之介",
		"川端康成",
		"三島由紀夫",
		"谷崎潤一郎"
	],
	"AMAZON.Book": [
		"人間失格",
		"吾輩は猫である",
		"坊ちゃん",
		"ノルウェーの森",
		"窓ぎわのトットちゃん",
		"バカの壁",
		"サラダ記念日",
		"道をひらく",
		"五体不満足",
		"日本沈没"
	],
	"AMAZON.City": [
		"渋谷",
		"新宿",
		"品川",
		"世田谷",
		"大阪"
	],
	"AMAZON.Color": [
		"赤",
		"白",
		"黄色",
		"黒",
		"緑",
		"紫",
		"青",
		"ピンク",
		"水色",
		"オレンジ色",
		"紺",
		"茶色",
		"黄緑",
		"ベージュ",
		"金色"
	],
	"AMAZON.Corporation": [
		"トヨタ",
		"ソニー",
		"パナソニック",
		"楽天",
		"サントリー",
		"ソフトバンク",
		"日産",
		"ホンダ",
		"日立",
		"任天堂",
		"日清食品",
		"全日空",
		"ブリジストン"
	],
	"AMAZON.Country": [
		"アメリカ",
		"米国",
		"中国",
		"韓国",
		"イギリス",
		"フランス",
		"ドイツ",
		"ロシア",
		"ブラジル",
		"タイ",
		"イタリア",
		"台湾",
		"北朝鮮",
		"シンガポール",
		"オーストラリア"
	],
	"AMAZON.CreativeWorkType": [
		"小説",
		"漫画",
		"映画",
		"ミュージカル",
		"詩",
		"俳句",
		"写真",
		"短歌",
		"CM",
		"歌"
	],
	"AMAZON.DayOfWeek": [
		"月曜日",
		"火曜日",
		"水曜日",
		"木曜日",
		"金曜日",
		"土曜日",
		"日曜日",
		"土日",
		"週末",
		"平日",
		"土曜",
		"日曜"
	],
	"AMAZON.FictionalCharacter": [
		"クレヨンしんちゃん",
		"アンパンマン",
		"スーパーマリオ",
		"ハリー・ポッター",
		"ガンダルフ",
		"トム・ソーヤ―",
		"トトロ",
		"ドラえもん",
		"ピカチュウ",
		"ミッキーマウス"
	],
	"AMAZON.FirstName": [
		"ヒロシ",
		"ハルキ",
		"ハルト",
		"ユウト",
		"ソウタ",
		"タカシ",
		"アキラ",
		"ダイスケ",
		"ケイコ",
		"ヨウコ",
		"ミチコ",
		"サチコ",
		"リエ",
		"アイ",
		"ユナ"
	],
	"AMAZON.Food": [
		"寿司",
		"すし",
		"餃子",
		"ラーメン",
		"カレーライス",
		"焼肉",
		"天ぷら",
		"刺身",
		"焼き魚",
		"すき焼き",
		"焼きそば",
		"うどん",
		"そば",
		"おにぎり",
		"味噌汁"
	],
	"AMAZON.Genre": [
		"J-pop",
		"ロック",
		"洋楽",
		"ビジネス",
		"エッセイ",
		"ドラマ",
		"バラエティ",
		"アニメ",
		"アクション",
		"コメディ"
	],
	"AMAZON.Language": [
		"日本語",
		"英語",
		"中国語",
		"韓国語",
		"フランス語",
		"ドイツ語",
		"スペイン語",
		"ポルトガル語",
		"ロシア語",
		"台湾語",
		"タガログ語",
		"フィリピン語",
		"ベトナム語",
		"タイ語",
		"インドネシア語"
	],
	"AMAZON.Month": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月"
	],
	"AMAZON.Movie": [
		"千と千尋の神隠し",
		"タイタニック",
		"君の名は。",
		"キングコング対ゴジラ",
		"ハリー・ポッターと賢者の石",
		"ハリー・ポッターとアズカバンの囚人",
		"ハウルの動く城",
		"もののけ姫",
		"ラストサムライ",
		"おくりびと",
		"踊る大捜査線 THE MOVIE 2 レインボーブリッジを封鎖せよ!",
		"崖の上のポニョ",
		"七人の侍",
		"アナと雪の女王",
		"E.T."
	],
	"AMAZON.MusicAlbum": [
		"First Love",
		"ティーンエイジ・ドリーム",
		"SWEET 19 BLUES",
		"レピュテーション",
		"A BEST",
		"ディバイド",
		"ストーリーズ",
		"リボルバー",
		"スリラー",
		"狂気"
	],
	"AMAZON.MusicGroup": [
		"AKB48",
		"TWICE",
		"funky monkey babys",
		"One Ok Rock",
		"嵐",
		"モーニング娘。",
		"SHINee",
		"東方神起",
		"コブクロ",
		"東京交響楽団"
	],
	"AMAZON.Musician": [
		"桑田佳祐",
		"福山雅治",
		"玉置浩二",
		"松任谷由実",
		"坂本龍一",
		"宇多田ヒカル",
		"小室哲哉",
		"矢沢永吉",
		"倖田來未",
		"小田和正"
	],
	"AMAZON.MusicRecording": [
		"川の流れのように",
		"桜坂",
		"名もなき詩",
		"インフルエンサー",
		"フライングゲット",
		"愛は勝つ",
		"とんぼ",
		"地上の星",
		"秋桜",
		"Ti Amo"
	],
	"AMAZON.Person": [
		"安倍総理大臣",
		"安倍総理",
		"安倍首相",
		"安倍晋三",
		"イチロー",
		"明石家さんま",
		"タモリ",
		"ビートたけし",
		"和田アキ子",
		"マツコ・デラックス",
		"黒柳徹子",
		"笑福亭鶴瓶",
		"アントニオ猪木",
		"中居正広",
		"松本人志"
	],
	"AMAZON.RadioChannel": [
		"TBSラジオ",
		"ニッポン放送",
		"NHK第一",
		"TOKYO FM",
		"J-WAVE",
		"NPR",
		"BBC Radio",
		"Kiss FM",
		"CNN",
		"大阪放送"
	],
	"AMAZON.Region": [
		"東京",
		"大阪",
		"京都",
		"関東",
		"関西"
	],
	"AMAZON.Room": [
		"キッチン",
		"台所",
		"リビング",
		"リビングルーム",
		"ダイニング",
		"ダイニングルーム",
		"茶の間",
		"座敷",
		"寝室",
		"玄関",
		"バスルーム",
		"トイレ",
		"風呂",
		"洗面所",
		"和室"
	],
	"AMAZON.Sport": [
		"野球",
		"サッカー",
		"ゴルフ",
		"相撲",
		"テニス",
		"ボクシング",
		"バレーボール",
		"フィギュアスケート",
		"柔道",
		"バスケットボール"
	],
	"AMAZON.StreetName": [
		"六本木",
		"西麻布",
		"恵比寿",
		"銀座",
		"原宿",
		"池袋",
		"丸の内",
		"有楽町",
		"代官山",
		"中目黒",
		"歌舞伎町",
		"新宿",
		"梅田",
		"天神",
		"渋谷"
	],
	"AMAZON.TVSeries": [
		"踊る大捜査線",
		"白い巨塔",
		"ドクターX",
		"古畑任三郎",
		"ドラえもん",
		"名探偵コナン",
		"アンパンマン",
		"ルパン三世",
		"相棒",
		"科捜研の女"
	],
	"AMAZON.VideoGame": [
		"Minecraft",
		"スーパーマリオブラザーズ",
		"ゼルダの伝説",
		"マリオカート",
		"ファイナルファンタジーXIV",
		"ドラゴンクエストX 目覚めし五つの種族 オンライン",
		"モンスターストライク",
		"Pokémon Go",
		"テトリス",
		"ポケットモンスター サン・ムーン"
	]
},
	"pt-br": {
	"AMAZON.Actor": [
		"Rodrigo Santoro",
		"Sônia Braga",
		"Lázaro Ramos",
		"Fernanda Montenegro",
		"Taís Araújo",
		"Johnny Depp",
		"Lupita Nyong'o",
		"Lucy Liu",
		"Morgan Freeman",
		"Leonardo DiCaprio"
	],
	"AMAZON.Airline": [
		"Gol Linhas Aereas",
		"LATAM Brasil",
		"Azul",
		"Lufthansa",
		"Varig",
		"American Airlines",
		"British Airways",
		"Icelandair",
		"United Airways",
		"Air India"
	],
	"AMAZON.Airport": [
		"Aeroporto Alberto Santos Dumont",
		"Aeroporto Internacional do Rio de Janeiro Tom Jobim Galeão",
		"Aeroporto Internacional de Belo Horizonte-Confins",
		"Aeroporto Sao Paulo Congonhas",
		"Aeroporto Sao Paulo Viracopos",
		"Aeroporto Paris Charles de Gaulle",
		"Aeroporto Internacional de Dublin",
		"Aeroporto Internacional New York J F Kennedy",
		"Aeroporto New York La Guardia",
		"Aeroporto Internacional Charlotte Douglas"
	],
	"AMAZON.Animal": [
		"jumento",
		"Mula",
		"capivara",
		"Onça-pintada",
		"Foca",
		"jabuti",
		"Macaco-Prego",
		"Lobo",
		"lontra",
		"Pardal"
	],
	"AMAZON.Artist": [
		"Wagner Moura",
		"Alinne Moraes",
		"Candido Portinari",
		"Chico Buarque",
		"Clarice Lispector",
		"Amy Winehouse",
		"Chris Rock",
		"Lucy Liu",
		"Georgia O'Keeffe",
		"Toni Morrison"
	],
	"AMAZON.Book": [
		"Onze Minutos",
		"O Milagre da Manhã",
		"O Conto da Aia",
		"O Alquimista",
		"Memorias póstumas de Blas Cubas",
		"Capitães da areia",
		"A Paixão segundo GH",
		"Quarto de Despejo",
		"Harry Potter e a Pedra Filosofal",
		"Dom Quixote de la Mancha"
	],
	"AMAZON.City": [
		"Belo Horizonte",
		"São Paulo",
		"Rio de Janeiro",
		"Curitiba",
		"Vitória",
		"New Orleans",
		"new york",
		"Paris",
		"dublin",
		"La Paz"
	],
	"AMAZON.Color": [
		"vermelho",
		"azul",
		"amarelo",
		"preto",
		"branco",
		"amarelas esverdeado",
		"neve",
		"rosa forte",
		"magenta quente",
		"Dourado pálido"
	],
	"AMAZON.Corporation": [
		"Amil",
		"Natura",
		"Batavo SA",
		"Grupo Globo",
		"Itaú Unibanco",
		"Microsoft",
		"Accenture",
		"Apple",
		"Google",
		"BMW"
	],
	"AMAZON.Country": [
		"Brasil",
		"Peru",
		"Bolívia",
		"Paraguai",
		"Uruguai",
		"Estados Unidos",
		"Grã-Bretanha",
		"China",
		"Rússia",
		"Canadá"
	],
	"AMAZON.CreativeWorkType": [
		"álbum",
		"ato",
		"cinematografia",
		"documentário",
		"foto",
		"jornal",
		"musical",
		"ópera",
		"romance",
		"video game"
	],
	"AMAZON.DayOfWeek": [
		"Quinta-feira",
		"Quinta",
		"Sexta-feira",
		"Domingo",
		"Segunda-feira",
		"Sábado",
		"Terça-feira",
		"Quarta-feira",
		"Sexta",
		"Segunda"
	],
	"AMAZON.FictionalCharacter": [
		"mônica",
		"Zé Carioca",
		"Harry Potter",
		"Fofão",
		"James Bond",
		"Pato Donald",
		"Sancho Pança",
		"cascão",
		"Capitu",
		"Chicó"
	],
	"AMAZON.FirstName": [
		"Maria",
		"Ana",
		"Francisca",
		"Antonia",
		"Adriana",
		"José",
		"João",
		"Antonio",
		"Francisco",
		"Carlos"
	],
	"AMAZON.Food": [
		"Strogonoff de frango",
		"Sashimi",
		"feijoada",
		"acarajé",
		"Pirão",
		"Pirarucu",
		"Pipoca",
		"pacu assado",
		"Milho Verde",
		"canjica"
	],
	"AMAZON.Genre": [
		"Mistério",
		"Fantasia",
		"Calypso",
		"Bossa nova",
		"Realismo mágico",
		"Impressionismo",
		"Comédia",
		"Flamenco",
		"Heavy metal",
		"Romance"
	],
	"AMAZON.Language": [
		"Inglês",
		"Espanhol",
		"Português",
		"Chinês",
		"Hindi",
		"Zulu",
		"Quéchua",
		"Japonês",
		"Língua brasileira de sinais",
		"Alemão"
	],
	"AMAZON.Month": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro"
	],
	"AMAZON.Movie": [
		"O Auto da Compadecida",
		"Central do Brasil",
		"Os Normais",
		"Minha Mãe é uma Peça",
		"A Hora da Estrela",
		"Titanic",
		"Eu, Eu Mesmo e Irene",
		"Harry Potter e O Enigma do Príncipe",
		"Dallas Buyers Club",
		"O Retorno da Família Addams"
	],
	"AMAZON.MusicAlbum": [
		"Amigos Para Sempre",
		"O Rappa - Acústico Oficina Francisco Brennand",
		"cassia eller ao vivo no rock in rio",
		"Duetos",
		"ana carolina",
		"Bad",
		"teenage dream",
		"art pop",
		"my love is your love",
		"Madonna"
	],
	"AMAZON.MusicGroup": [
		"Bob Marley",
		"Ed Sheeran",
		"Evanescence",
		"Rihanna",
		"Shakira",
		"Pitty",
		"Pabllo Vittar",
		"Renato Russo",
		"Tonico & Tinoco",
		"Cássia Eller"
	],
	"AMAZON.Musician": [
		"Bob Marley",
		"Ed Sheeran",
		"Evanescence",
		"Rihanna",
		"Shakira",
		"Pitty",
		"Pabllo Vittar",
		"Renato Russo",
		"Tonico & Tinoco",
		"Cássia Eller"
	],
	"AMAZON.MusicRecording": [
		"Construção",
		"Eu Quero Tchu Eu Quero Tcha",
		"Garota de Ipanema",
		"Old Town Road",
		"Pedro Navaja",
		"Você Partiu Meu Coração",
		"Shape of You",
		"Eine kleine Nachtmusik",
		"Stairway to Heaven",
		"Morena"
	],
	"AMAZON.Person": [
		"Cláudia Raia",
		"Matheus Nachtergaele",
		"Patrícia Pillar",
		"Caco Ciocler",
		"Patrícia Poeta",
		"Candido Portinari",
		"Laura Pausini",
		"Steven Spielberg",
		"Rihanna",
		"Paulo Coelho"
	],
	"AMAZON.RadioChannel": [
		"Rádio Extra 103.9 FM",
		"Radio Jovempan 100.9 FM",
		"Antena 1",
		"Rádio Globo",
		"Rádio Mix 101.1 FM",
		"Radio ABC 94.7 FM",
		"Radio BBC 2 89.1 FM",
		"NBC Sports",
		"CBN-FM",
		"Radio ABC News 630 AM"
	],
	"AMAZON.Region": [
		"São Paulo",
		"Amazonas",
		"Pará",
		"Mato Grosso",
		"Região Nordeste",
		"Região Centro Oeste",
		"Região Norte",
		"Região Sudeste",
		"Região Sul",
		"Microrregião do Rio de Janeiro"
	],
	"AMAZON.Room": [
		"escritório",
		"sótão",
		"porão",
		"laboratório de informática",
		"dormitório",
		"estúdio",
		"oficina",
		"salão",
		"ginásio",
		"galpão"
	],
	"AMAZON.Sport": [
		"futebol",
		"Capoeira",
		"Jiu-jitsu",
		"Vôlei",
		"Basquete",
		"Natação",
		"Tênis",
		"Atletismo",
		"Surfe",
		"Automobilismo"
	],
	"AMAZON.StreetName": [
		"rua grão pará",
		"rua padre pedro pinto",
		"rua saara",
		"rua dos bandeirantes",
		"rua do ouro",
		"rua madre teresa de calcuta",
		"Avenida Silviano Brandão",
		"avenida cristiano machado",
		"avenida do contorno",
		"Avenida Afonso Pena"
	],
	"AMAZON.TVSeries": [
		"Os Normais",
		"a grande família",
		"Chaves",
		"Toma Lá Dá Cá",
		"Sai de Baixo",
		"Friends",
		"24 Horas",
		"Game of Thrones",
		"Gilmore Girls: Tal Mãe, Tal Filha",
		"Smallville: As Aventuras do Superboy"
	],
	"AMAZON.VideoGame": [
		"Overwatch",
		"Persona 5",
		"Legend of Zelda: Breath of the Wild",
		"Pokemon Sword",
		"Transistor",
		"Beat Saber",
		"Death Stranding",
		"Vampire: The Masquerade - Bloodlines 2",
		"Cyberpunk 2077",
		"Into the Breach"
	]
},
	"es-es": {
	"AMAZON.Actor": [
		"Antonio Banderas",
		"Penélope Cruz",
		"Javier Bardem",
		"Clara Lago",
		"Mario Casas",
		"Imanol Arias",
		"Blanca Suárez",
		"María Valverde",
		"Elsa Pataky",
		"Raúl Arévalo",
		"Luis Tosar",
		"Hugo Silva",
		"Paz Vega",
		"Ernesto Alterio",
		"Carmen Maura"
	],
	"AMAZON.Airline": [
		"Iberia",
		"Vueling",
		"Air Europa",
		"Air Nostrum",
		"RyanAir",
		"easyJet",
		"British Airways",
		"Air France",
		"Lufthansa",
		"Binter Canarias"
	],
	"AMAZON.Airport": [
		"Aeropuerto Adolfo Suárez Madrid Barajas",
		"Aeropuerto de Barcelona El Prat",
		"Aeropuerto de Palma de Mallorca",
		"Aeropuerto de Málaga Costa del Sol",
		"Aeropuerto de Gran Canaria",
		"Aeropuerto Internacional John F. Kennedy",
		"Aeropuerto Internacional Hamad",
		"Aeropuerto Internacional de la Ciudad de México",
		"Aeropuerto de Londres Heathrow",
		"Aeropuerto de Frankfurt"
	],
	"AMAZON.Animal": [
		"Águila",
		"Caballo",
		"perro",
		"Zorro rojo",
		"panda",
		"pez",
		"Boston terrier",
		"Oso negro americano",
		"Pastor vasco",
		"Paíño europeo"
	],
	"AMAZON.Artist": [
		"Pablo Picasso",
		"Salvador Dalí",
		"Joan Miró",
		"El Greco",
		"Diego Velázquez",
		"Antoni Gaudí",
		"Juan Gris",
		"Luisa Roldán",
		"Brad Pitt",
		"Penélope Cruz"
	],
	"AMAZON.Book": [
		"Fariña",
		"Patria",
		"Sapiens",
		"Don Quijote de la Mancha",
		"Cantar de Mío Cid",
		"La vida del Buscón",
		"El alcalde de Zalamea",
		"El ruido y la furia",
		"La ciudad y los perros",
		"Veinte poemas de amor y una canción desesperada"
	],
	"AMAZON.City": [
		"Madrid",
		"Barcelona",
		"Valencia",
		"Sevilla",
		"Palma",
		"Las Palmas de Gran Canaria",
		"Valladolid",
		"Alicante"
	],
	"AMAZON.Color": [
		"Rojo",
		"naranja",
		"amarillo",
		"verde",
		"azul",
		"púrpura",
		"magenta",
		"turquesa",
		"Violeta",
		"oro",
		"rosado",
		"marrón",
		"negro"
	],
	"AMAZON.Corporation": [
		"Repsol",
		"Banco Santander",
		"Inditex",
		"Iberdrola",
		"HSBC",
		"Apple",
		"Johnson & Johnson",
		"Amazon.com",
		"Alphabet Inc.",
		"Tesla Motors"
	],
	"AMAZON.Country": [
		"España",
		"Estados Unidos",
		"México",
		"Japón",
		"Rusia",
		"Marruecos",
		"Canadá",
		"Italia",
		"Australia",
		"Ecuador",
		"Francia",
		"Ucrania",
		"Argentina",
		"India",
		"Brasil",
		"Nueva Zelanda"
	],
	"AMAZON.CreativeWorkType": [
		"Ópera",
		"Revista",
		"Libro",
		"Telenovela",
		"Serie",
		"Programa",
		"Obra de teatro",
		"Musical",
		"película",
		"oración"
	],
	"AMAZON.DayOfWeek": [
		"Martes",
		"Lunes",
		"Jueves",
		"Domingo",
		"Viernes",
		"Miércoles",
		"Sábado"
	],
	"AMAZON.FictionalCharacter": [
		"Zorro",
		"Batman",
		"Anthony Oda",
		"Natalia Rivera Aitoro",
		"Blue Man",
		"Detective Hill",
		"Mrs. Signatelli",
		"Auntie Frida",
		"Dr. Fred Fonseca",
		"Valentina La Paz"
	],
	"AMAZON.FirstName": [
		"antonio",
		"jose",
		"manuel",
		"francisco",
		"juan",
		"luisa",
		"isabel",
		"marta"
	],
	"AMAZON.Food": [
		"paella",
		"carne de cordero",
		"jamón serrano",
		"pollo",
		"tarta de manzana",
		"tortilla de patatas",
		"magdalenas",
		"gazpacho",
		"patatas bravas",
		"churro"
	],
	"AMAZON.Genre": [
		"Flamenco",
		"Reguetón",
		"Rómantica",
		"Novela histórica",
		"Ciencia Ficción Infantil",
		"Ficción",
		"Comedia",
		"Suspenso",
		"Drama",
		"Documental"
	],
	"AMAZON.Language": [
		"Catalán",
		"Gallego",
		"Euskera",
		"Vasco",
		"Castellano",
		"Español",
		"Inglés",
		"Alemán",
		"Italiano",
		"Árabe"
	],
	"AMAZON.Month": [
		"Enero",
		"Abril",
		"Mayo",
		"Septiembre",
		"Diciembre",
		"Febrero",
		"Marzo",
		"Junio",
		"Julio",
		"Agosto",
		"Octubre",
		"Noviembre"
	],
	"AMAZON.Movie": [
		"Un monstruo viene a verme",
		"Lo imposible",
		"Lo que el viento se llevó",
		"Ocho apellidos vascos",
		"Los Otros",
		"Blade Runner",
		"La máscara del Zorro",
		"Los pitufos",
		"Tres metros sobre el cielo",
		"Infiltrados"
	],
	"AMAZON.MusicAlbum": [
		"Más",
		"Corazón latino",
		"Descanso dominical",
		"El viaje de Copperpot",
		"Divide",
		"Raíces",
		"Havana",
		"25",
		"Beautiful Lies",
		"Prometo"
	],
	"AMAZON.MusicGroup": [
		"Daniel Barenboim",
		"Alejandro Sanz",
		"Luis Miguel",
		"Manu Chao",
		"Enrique Iglesias",
		"Julio Iglesias",
		"David Bisbal",
		"Ed Sheeran",
		"Imagine Dragons",
		"Bruno Mars"
	],
	"AMAZON.Musician": [
		"Rozalén",
		"Melendi",
		"Shakira",
		"Luis Miguel",
		"Queen",
		"Ed Sheeran",
		"Julio Iglesias",
		"Camilo Sesto",
		"John Mayer",
		"Taylor Swift"
	],
	"AMAZON.MusicRecording": [
		"Despacito",
		"Dura",
		"Macarena",
		"Calma",
		"La Bamba",
		"Mayores",
		"Imposible",
		"Bailando",
		"Danza Kuduro",
		"Mi Gente"
	],
	"AMAZON.Person": [
		"Enrique Iglesias",
		"Penélope Cruz",
		"Javier Bardem",
		"Antonio Banderas",
		"Gerard Piqué",
		"Pablo Picasso",
		"Salvador Dalí",
		"Pau Gasol",
		"Letizia Ortiz",
		"Xabi Alonso",
		"Mariano Rajoy",
		"Miguel de Cervantes"
	],
	"AMAZON.RadioChannel": [
		"Rac 1",
		"Onda Cero",
		"Cadena Cope",
		"Los40",
		"Cadena SER",
		"Radio Swiss Classic",
		"Heart London",
		"Europe 1",
		"BBC Radio 1",
		"ESPN Deportes Radio"
	],
	"AMAZON.Region": [
		"Cantabria",
		"Castilla-La Mancha",
		"Comunidad de Madrid",
		"Comunidad Foral de Navarra",
		"Comunidad Valenciana",
		"Extremadura",
		"Galicia",
		"Principado de Asturias"
	],
	"AMAZON.Room": [
		"Cocina",
		"Dormitorio",
		"Ático",
		"Comedor",
		"Biblioteca",
		"Sala",
		"Estudio",
		"Baño",
		"Habitación",
		"Bodega"
	],
	"AMAZON.Sport": [
		"Fútbol",
		"Baloncesto",
		"Ciclismo",
		"Tenis",
		"Balonmano",
		"Natación",
		"Atletismo",
		"Gimnasia Rítmica",
		"Fútbol Sala",
		"Boxeo"
	],
	"AMAZON.StreetName": [
		"Calle Mayor",
		"Calle Iglesia",
		"Calle Real",
		"Calle Nueva",
		"Avenida de la Constitución",
		"Paseo de Gracia",
		"Paseo de la Castellana",
		"Gran Vía",
		"Calle San Juan",
		"Paseo Marítimo"
	],
	"AMAZON.TVSeries": [
		"Los Soprano",
		"El Ala Oeste de la Casa Blanca",
		"A dos metros bajo tierra",
		"Los serrano",
		"Águila Roja",
		"La que se avecina",
		"Las 4 estaciones de las chicas Gilmore",
		"Ingobernable",
		"American Vandal",
		"Anne with an E"
	],
	"AMAZON.VideoGame": [
		"La Pulga",
		"La Abadía del Crimen",
		"Clash Royale",
		"Diablo III",
		"Angry Birds",
		"Overwatch",
		"God of War",
		"Super Mario Odyssey",
		"The Legend of Zelda",
		"Call of Duty: WWII"
	]
},
	"es-mx": {
	"AMAZON.Actor": [
		"Pedro Infante",
		"Cantinflas",
		"Salma Hayek",
		"Lupita Nyong'o",
		"Anthony Quinn",
		"Kate del Castillo",
		"Katy Jurado",
		"Gael García",
		"Diego Boneta",
		"Diego Luna"
	],
	"AMAZON.Airline": [
		"Avianca",
		"Aeroméxico",
		"Interjet",
		"Volaris",
		"VivaAerobus",
		"United Airlines",
		"Latam",
		"Aeromar",
		"Copa Airlines",
		"JetBlue Airways"
	],
	"AMAZON.Airport": [
		"Aeropuerto Internacional Benito Juárez",
		"Aeropuerto Internacional de Cancún",
		"Aeropuerto Internacional de Guadalajara",
		"Aeropuerto Internacional General Abelardo L. Rodríguez",
		"Aeropuerto Internacional John F. Kennedy",
		"Aeropuerto Adolfo Suárez Madrid Barajas",
		"Aeropuerto Internacional Jorge Chavez",
		"Aeropuerto Internacional de Guarulhos",
		"Aeropuerto Internacional El Dorado",
		"Aeropuerto de París Charles de Gaulle"
	],
	"AMAZON.Animal": [
		"Águila",
		"Caballo",
		"perro",
		"Zorro rojo",
		"panda",
		"pez",
		"Boston terrier",
		"Oso negro americano",
		"Pastor vasco",
		"Paíño europeo"
	],
	"AMAZON.Artist": [
		"Frida Kahlo",
		"Diego Rivera",
		"Remedios Varo",
		"Luis Miguel",
		"Paulina Rubio",
		"Salma Hayek",
		"Gael García Bernal",
		"Carlos Fuentes",
		"Juan Rulfo",
		"Fey"
	],
	"AMAZON.Book": [
		"Cien Años de Soledad",
		"El libro negro",
		"La visión de los vencidos",
		"El laberinto de la soledad",
		"Cartucho",
		"Thinking, Fast and Slow",
		"El mundo de Sofía",
		"El Llano en llamas",
		"Como agua para chocolate",
		"Don Quijote de la Mancha"
	],
	"AMAZON.City": [
		"Mexico City",
		"Ecatepec",
		"Guadalajara",
		"Puebla",
		"New York City",
		"Ciudad Juárez",
		"León",
		"Monterrey"
	],
	"AMAZON.Color": [
		"Rosa",
		"Verde",
		"Rojo",
		"Morado",
		"Amarillo",
		"Azul",
		"Turquesa",
		"Naranja",
		"Café",
		"Negro"
	],
	"AMAZON.Corporation": [
		"América Móvil",
		"Grupo México",
		"Microsoft",
		"Apple",
		"Bayer",
		"Toyota",
		"Nestlé",
		"Grupo Bimbo",
		"Corona",
		"Amazon.com"
	],
	"AMAZON.Country": [
		"México",
		"El Salvador",
		"Guatemala",
		"Alemania",
		"Italia",
		"Australia",
		"Jordania",
		"India",
		"China",
		"Brasil"
	],
	"AMAZON.CreativeWorkType": [
		"Calaveritas Literarias",
		"Canción",
		"Adivinanza",
		"Telenovela",
		"Pintura",
		"Obra de teatro",
		"Película",
		"Himno",
		"danza",
		"Cuento"
	],
	"AMAZON.DayOfWeek": [
		"Miércoles",
		"Jueves",
		"Viernes",
		"Lunes",
		"Martes",
		"Sábado",
		"Domingo"
	],
	"AMAZON.FictionalCharacter": [
		"Zorro",
		"Batman",
		"Anthony Oda",
		"Natalia Rivera Aitoro",
		"Blue Man",
		"Detective Hill",
		"Mrs. Signatelli",
		"Auntie Frida",
		"Dr. Fred Fonseca",
		"Valentina La Paz"
	],
	"AMAZON.FirstName": [
		"José Luis",
		"Juan",
		"Miguel Ángel",
		"José",
		"Francisco",
		"Jesús",
		"Antonio",
		"María Guadalupe",
		"María",
		"Juana",
		"María del Carmen",
		"Margarita",
		"Elizabeth"
	],
	"AMAZON.Food": [
		"frijoles pintos",
		"jalapeño",
		"huevo",
		"jamón",
		"tortilla",
		"mole",
		"chilaquiles",
		"enchiladas",
		"tamales",
		"tacos"
	],
	"AMAZON.Genre": [
		"Corrido",
		"Ranchera",
		"Copla",
		"Fantasía",
		"Ciencia ficción",
		"Concurso",
		"Telenovela",
		"Documental",
		"Acción",
		"Comedia ranchera"
	],
	"AMAZON.Language": [
		"Castellano",
		"Español",
		"Inglés",
		"Portugués",
		"Italiano",
		"Árabe",
		"Náhuatl",
		"Maya Yucateco",
		"Mixteco",
		"Alemán"
	],
	"AMAZON.Month": [
		"Enero",
		"Marzo",
		"Mayo",
		"Septiembre",
		"Diciembre",
		"Febrero",
		"Abril",
		"Junio",
		"Julio",
		"Agosto",
		"Octubre",
		"Noviembre"
	],
	"AMAZON.Movie": [
		"Coco",
		"Hombre al agua",
		"Pantera Negra",
		"No Manches Frida",
		"El Exorcista",
		"Amores perros",
		"Nosotros los pobres",
		"Avengers Infinity War",
		"Jurassic world el reino caído",
		"El espíritu de la colmena"
	],
	"AMAZON.MusicAlbum": [
		"Abbey Road",
		"Pies descalzos",
		"Thriller",
		"Supernatural",
		"Romance",
		"¿Dónde jugarán los niños?",
		"Master of Puppets",
		"Nevermind",
		"The Wall",
		"Amor prohibido"
	],
	"AMAZON.MusicGroup": [
		"Molotov",
		"Mana",
		"Luis Miguel",
		"Carlos Santana",
		"Freddy Fender",
		"Lucero",
		"Maite Perroni",
		"Selena Gomez",
		"Ed Sheeran",
		"The Beatles"
	],
	"AMAZON.Musician": [
		"Gloria Trevi",
		"Carla Morrison",
		"Luis Miguel",
		"Carlos Santana",
		"Julieta Venegas",
		"Selena",
		"Perez Prado",
		"Ely Guerra",
		"Lucero",
		"Maite Perroni"
	],
	"AMAZON.MusicRecording": [
		"Perfect",
		"Faded",
		"High Hopes",
		"I Like it",
		"in my mind",
		"para siempre",
		"calma",
		"sunflower",
		"lost on you",
		"zero"
	],
	"AMAZON.Person": [
		"Enrique Peña Nieto",
		"Andrés Manuel López Obrador",
		"Emiliano Zapata",
		"Benito Juarez",
		"Diana De Gales",
		"Simón Bolívar",
		"Antonio Banderas",
		"Selena Gomez",
		"Salma Hayek",
		"Carlos Fuentes"
	],
	"AMAZON.RadioChannel": [
		"Exa",
		"Los 40 Principales",
		"W Radio",
		"Universal",
		"CNN en Español",
		"Onda Cero",
		"Radio Habana Cuba",
		"Radio Disney Latinoamérica",
		"ESPN Deportes Radio"
	],
	"AMAZON.Region": [
		"México",
		"Ciudad de México",
		"Puebla",
		"Guanajuato",
		"Nuevo León",
		"Baja California"
	],
	"AMAZON.Room": [
		"Cocina",
		"Comedor",
		"Baño",
		"Azotea",
		"Biblioteca",
		"Sala",
		"Estudio",
		"Cuarto",
		"Guarida",
		"Patio"
	],
	"AMAZON.Sport": [
		"Fútbol",
		"Básquetbol",
		"Béisbol",
		"Fútbol Americano",
		"Atletismo",
		"Tenis",
		"Natación",
		"Box",
		"Lucha libre",
		"Automovilismo"
	],
	"AMAZON.StreetName": [
		"Calle Miguel Hidalgo",
		"Calle Emiliano Zapata",
		"Avenida Cinco de Mayo",
		"Avenida Dieciséis De Septiembre",
		"Avenida Álvaro Obregón",
		"Avenida Chapultepec",
		"Avenida de los Insurgentes",
		"Calle Madero",
		"Calzada de Guadalupe"
	],
	"AMAZON.TVSeries": [
		"El Chapo",
		"The Ranch",
		"House of Cards",
		"Gilmore Girls",
		"Soy Tu Fan",
		"Ingobernable",
		"La casa de las flores",
		"Los ricos también lloran",
		"Cuna de lobos",
		"La impostora"
	],
	"AMAZON.VideoGame": [
		"God of War",
		"Halo 5",
		"Mario Kart 8",
		"League of Legends",
		"World of Warcraft",
		"Minecraft",
		"Angry Birds",
		"Candy Crush",
		"Super Mario Bros.",
		"The Legend of Zelda"
	]
},
	"es-us": {
	"AMAZON.Actor": [
		"Pedro Infante",
		"Cantinflas",
		"Salma Hayek",
		"Lupita Nyong'o",
		"Anthony Quinn",
		"Kate del Castillo",
		"Katy Jurado",
		"Diego Boneta",
		"Diego Luna",
		"Chris Evans"
	],
	"AMAZON.Airline": [
		"Southwest Airlines",
		"Delta Air Lines",
		"Lufthansa",
		"British Airways",
		"Air France",
		"Aeroflot",
		"Etihad Airways",
		"Air China",
		"Aeroméxico",
		"United Airlines"
	],
	"AMAZON.Airport": [
		"Dulles International Airport",
		"London Heathrow",
		"Aeropuerto de León",
		"JFK International Airport",
		"Aeropuerto Internacional Libertad de Newark",
		"LAX",
		"La Paz International Airport",
		"Aeropuerto de Florencia",
		"Atlanta Airport",
		"Cologne Airport"
	],
	"AMAZON.Animal": [
		"Fox",
		"Elephant",
		"Chicken",
		"Tigre",
		"Ermine",
		"Chimpancé",
		"Boston Terrier",
		"Wolf Spider",
		"León marino",
		"Libélula"
	],
	"AMAZON.Artist": [
		"Juan Rulfo",
		"Carlos Fuentes",
		"Fey",
		"Pablo Picasso",
		"Taylor Swift",
		"Lady Gaga",
		"Diego Rivera",
		"Salma Hayek",
		"Luis Miguel",
		"Ed Sheeran"
	],
	"AMAZON.Book": [
		"Cincuenta sombras de Grey",
		"La invención de Morel",
		"Baudolino",
		"Cuentos completos",
		"Harry Potter y la cámara secreta",
		"The Crucible",
		"The Grapes of Wrath",
		"Siddhartha",
		"The Catcher in the Rye",
		"Sapiens: A Brief History of Humankind"
	],
	"AMAZON.City": [
		"Rio de Janeiro",
		"Córdoba",
		"New York City",
		"Atlanta",
		"Paris",
		"Berlin",
		"Cape Town",
		"Beijing",
		"London",
		"Moscow"
	],
	"AMAZON.Color": [
		"red",
		"blue",
		"green",
		"yellow",
		"orange",
		"rosado",
		"gris",
		"azul",
		"rojo",
		"pink"
	],
	"AMAZON.Corporation": [
		"Toyota",
		"General Electric",
		"Amazon.com",
		"Costco",
		"Johnson & Johnson",
		"American Express",
		"BBC",
		"Nintendo",
		"Facebook",
		"ExxonMobil"
	],
	"AMAZON.Country": [
		"India",
		"England",
		"Columbia",
		"Indonesia",
		"Nigeria",
		"Iraq",
		"Ecuador",
		"Eritrea",
		"Somalia",
		"Laos"
	],
	"AMAZON.CreativeWorkType": [
		"ballet",
		"rap",
		"mural",
		"musical",
		"makeup",
		"calavera literaria",
		"graffiti",
		"mito",
		"song",
		"documental"
	],
	"AMAZON.DayOfWeek": [
		"Saturday",
		"viernes",
		"lunes",
		"thursday",
		"weekdays",
		"martes",
		"monday",
		"domingo",
		"wednesday",
		"the weekend"
	],
	"AMAZON.FictionalCharacter": [
		"superman",
		"batman",
		"homer simpson",
		"zorro",
		"james bond",
		"Pikachu",
		"snoopy",
		"nemo",
		"pongo",
		"bert"
	],
	"AMAZON.FirstName": [
		"Mari",
		"Andrea",
		"Ricardo",
		"Julia",
		"Jan",
		"Anna",
		"Jeff",
		"Beatriz",
		"Alex",
		"Ramon"
	],
	"AMAZON.Food": [
		"parfait",
		"macaron",
		"cookies and cream ice cream",
		"red velvet cake",
		"frijoles",
		"chilaquiles",
		"edamame",
		"lamington",
		"manzana",
		"peanut butter cookie"
	],
	"AMAZON.Genre": [
		"Zapateado",
		"hardcore punk",
		"screamo",
		"literatura carcelaria",
		"weird west",
		"corrido",
		"tech house",
		"kabuki",
		"docudrama",
		"deporte"
	],
	"AMAZON.Language": [
		"arabic",
		"spanish",
		"english",
		"french",
		"cebuano",
		"ibibio",
		"sotho",
		"sindhi",
		"mossi",
		"fang"
	],
	"AMAZON.Month": [
		"mayo",
		"December",
		"febrero",
		"november",
		"january",
		"abril",
		"octubre",
		"julio",
		"junio",
		"june"
	],
	"AMAZON.Movie": [
		"lord of the rings",
		"como agua para chocolate",
		"It",
		"Titanic",
		"Moulin Rouge",
		"Casablanca",
		"The Help",
		"The Comedian",
		"Read it and Weep",
		"Thanks"
	],
	"AMAZON.MusicAlbum": [
		"Thriller",
		"Highway to Hell",
		"Rise",
		"25",
		"Leave a Light On",
		"First Time",
		"No Roots",
		"I'll Be There",
		"Human",
		"Rumours"
	],
	"AMAZON.MusicGroup": [
		"The Beatles",
		"Taylor Swift",
		"Imagine Dragons",
		"Michael Jackson",
		"Panic! At The Disco",
		"Elvis Presley",
		"AC/DC",
		"Zac Brown Band",
		"Metallica",
		"Coldplay"
	],
	"AMAZON.Musician": [
		"Taylor Swift",
		"Bruno Mars",
		"Michael Jackson",
		"Drake",
		"Elvis Presley",
		"Eminem",
		"Selena Gomez",
		"Ariana Grande",
		"Justin Timberlake",
		"Adele"
	],
	"AMAZON.MusicRecording": [
		"Believer",
		"Leave a Light On",
		"Feel It Still",
		"One Kiss",
		"Closer",
		"Uptown Funk",
		"Never Enough",
		"True Colors",
		"Shape of You",
		"Say Something"
	],
	"AMAZON.Person": [
		"jimmy carter",
		"marilyn monroe",
		"ernest hemingway",
		"abraham lincoln",
		"kim kardashian",
		"george washington",
		"noam chomsky",
		"barack obama",
		"babe ruth",
		"john steinbeck"
	],
	"AMAZON.RadioChannel": [
		"capital radio",
		"cinemagic",
		"horizon fm",
		"kapn",
		"krus",
		"the superstation",
		"star one thousand sixty nine business",
		"big fm",
		"kiss fm",
		"bbc world service"
	],
	"AMAZON.Region": [
		"Alabama",
		"Ohio",
		"Guam",
		"Massachusetts",
		"Texas",
		"Jersey County",
		"Provincia de Galápagos",
		"Condado de Santa Fe",
		"Jalisco",
		"Oregon"
	],
	"AMAZON.Room": [
		"dining room",
		"garage",
		"pasillo",
		"entryway",
		"basement",
		"studio",
		"vestidor",
		"patios traseros",
		"dormitorios",
		"galley"
	],
	"AMAZON.Sport": [
		"softball",
		"ping pong",
		"british baseball",
		"atletismo",
		"squash sport",
		"remo",
		"cinco teros",
		"dodgeball",
		"sailing",
		"tennis polo"
	],
	"AMAZON.StreetName": [
		"Main St",
		"church Street",
		"Pine Street",
		"Elm Street",
		"Oak Street",
		"Maple Street",
		"Central Avenue",
		"Circle Drive",
		"Cherry Street",
		"Shady Lane"
	],
	"AMAZON.TVSeries": [
		"Teenage Mutant Ninja Turtles",
		"Lost",
		"Supernatural",
		"The Twilight Zone",
		"Game of Thrones",
		"The Walking Dead",
		"NCIS",
		"Family Guy",
		"Friends",
		"The Big Bang Theory"
	],
	"AMAZON.VideoGame": [
		"grand theft auto",
		"sword art online",
		"breath of fire",
		"left 4 dead",
		"super mario bros.",
		"minecraft",
		"final fantasy",
		"call of duty 3",
		"gran turismo",
		"kingdom hearts"
	]
}
};

var builtinslottypesamples$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  'default': builtinslottypesamples
});

function getCjsExportFromNamespace (n) {
	return n && n['default'] || n;
}

var SLOT_TYPE_SAMPLES = getCjsExportFromNamespace(slottypesamples$1);

var BUILTIN_SLOT_TYPE_SAMPLES = getCjsExportFromNamespace(builtinslottypesamples$1);

const debug$3 = debug$5('botium-connector-lex-slottypes');
const {
  Defaults: Defaults$1
} = connector;
const loadSlotTypes$2 = language => {
  const slotTypes = {};
  const builtinLangKey = Object.keys(BUILTIN_SLOT_TYPE_SAMPLES).find(l => language.startsWith(l));
  if (builtinLangKey) {
    Object.assign(slotTypes, BUILTIN_SLOT_TYPE_SAMPLES[builtinLangKey]);
  }
  const langKey = Object.keys(SLOT_TYPE_SAMPLES).find(l => language.startsWith(l));
  if (langKey) {
    Object.assign(slotTypes, SLOT_TYPE_SAMPLES[langKey]);
  }
  debug$3(`Loaded slot type samples for: ${Object.keys(slotTypes)}`);
  return slotTypes;
};
const paginatedCall$2 = async (fnc, extract, args = {}, aggregateddata = []) => {
  const data = await fnc({
    maxResults: 50,
    ...args
  }).promise();
  if (data.nextToken) {
    return paginatedCall$2(fnc, {
      maxResults: 50,
      ...args,
      nextToken: data.nextToken
    }, [...aggregateddata, ...(extract(data) || [])]);
  } else {
    return [...aggregateddata, ...(extract(data) || [])];
  }
};
const loadCustomSlotTypes$2 = async (client, caps) => {
  const customSlotTypes = {};
  if (caps.LEX_VERSION === 'V1') {
    const slotTypesShort = await paginatedCall$2(client.getSlotTypes.bind(client), d => d.slotTypes, {});
    for (const slotTypeShort of slotTypesShort) {
      const st = await client.getSlotType({
        name: slotTypeShort.name,
        version: '$LATEST'
      }).promise();
      if (st.enumerationValues && st.enumerationValues.length > 0) {
        customSlotTypes[`${st.name}`] = st.enumerationValues.map(e => e.value);
      }
    }
  } else {
    const botParams = {
      botId: caps.LEX_PROJECT_NAME,
      botVersion: caps.LEX_PROJECT_VERSION,
      localeId: caps.LEX_LOCALE || Defaults$1.LEX_LOCALE
    };
    const slotTypesShort = await paginatedCall$2(client.listSlotTypes.bind(client), d => d.slotTypeSummaries, {
      ...botParams
    });
    for (const slotTypeShort of slotTypesShort) {
      const st = await client.describeSlotType({
        ...botParams,
        slotTypeId: slotTypeShort.slotTypeId
      }).promise();
      if (st.slotTypeValues && st.slotTypeValues.length > 0) {
        customSlotTypes[`${st.slotTypeId}`] = st.slotTypeValues.map(e => e.sampleValue.value);
      }
    }
  }
  debug$3(`Loaded custom slot type samples for: ${Object.keys(customSlotTypes)}`);
  return customSlotTypes;
};
const expandSlotType$2 = (sample, slotName, slotSamples) => {
  const result = [];
  slotSamples.forEach(ss => {
    result.push(sample.replace(`{${slotName}}`, ss));
  });
  return result;
};
const reSlots = /{(.*?)}/g;
const extractSlotNames$1 = sample => {
  const reMatches = (sample.match(reSlots) || []).map(e => RegExp(reSlots.source, reSlots.flags).exec(e));
  if (reMatches.length > 0) {
    return lodash.sortBy(lodash.uniq(reMatches.map(r => r[1])));
  }
  return [];
};
var slottypes = {
  paginatedCall: paginatedCall$2,
  loadSlotTypes: loadSlotTypes$2,
  loadCustomSlotTypes: loadCustomSlotTypes$2,
  expandSlotType: expandSlotType$2,
  extractSlotNames: extractSlotNames$1
};

const debug$2 = debug$5('botium-connector-lex-nlp');
const {
  loadSlotTypes: loadSlotTypes$1,
  loadCustomSlotTypes: loadCustomSlotTypes$1,
  expandSlotType: expandSlotType$1
} = slottypes;
const timeout$1 = ms => new Promise(resolve => setTimeout(resolve, ms));
const getCaps = caps => {
  const result = Object.assign({}, caps || {});
  return result;
};
const extractIntentUtterances$1 = async ({
  caps
}) => {
  const driver = new botiumCore.BotDriver(getCaps(caps));
  if (driver.caps.LEX_VERSION !== 'V1') throw new Error('Only supported for Lex Version 1');
  const botName = driver.caps.LEX_PROJECT_NAME;
  const botAlias = driver.caps.LEX_PROJECT_ALIAS;
  const client = new awsSdk.LexModelBuildingService({
    apiVersion: '2017-04-19',
    region: driver.caps.LEX_REGION,
    accessKeyId: driver.caps.LEX_ACCESS_KEY_ID,
    secretAccessKey: driver.caps.LEX_SECRET_ACCESS_KEY
  });
  const builtinSlotTypes = await loadSlotTypes$1('en-us');
  debug$2(`Loaded ${Object.keys(builtinSlotTypes).length} built-in slot types`);
  const customSlotTypes = await loadCustomSlotTypes$1(client);
  debug$2(`Loaded ${Object.keys(customSlotTypes).length} custom slot types`);
  const bot = await client.getBot({
    name: botName,
    versionOrAlias: botAlias
  }).promise();
  const intents = [];
  for (const intent of bot.intents || []) {
    const botIntent = await client.getIntent({
      version: intent.intentVersion,
      name: intent.intentName
    }).promise();
    let utterances = botIntent.sampleUtterances || [];
    for (const slot of botIntent.slots) {
      const slotMatch = `{${slot.name}}`;
      utterances = utterances.reduce((result, utterance) => {
        if (utterance.indexOf(slotMatch) > 0) {
          if (customSlotTypes[slot.slotType]) {
            result = [...result, ...expandSlotType$1(utterance, slot.name, customSlotTypes[slot.slotType])];
          } else if (builtinSlotTypes[slot.slotType]) {
            result = [...result, ...expandSlotType$1(utterance, slot.name, builtinSlotTypes[slot.slotType])];
          }
        } else {
          result = [...result, utterance];
        }
        return result;
      }, []);
    }
    intents.push({
      intentName: intent.intentName,
      utterances: utterances
    });
  }
  return {
    intents,
    origBot: bot
  };
};
const trainIntentUtterances$1 = async ({
  caps
}, intents, {
  origBot
}) => {
  const driver = new botiumCore.BotDriver(getCaps(caps));
  if (driver.caps.LEX_VERSION !== 'V1') throw new Error('Only supported for Lex Version 1');
  const client = new awsSdk.LexModelBuildingService({
    apiVersion: '2017-04-19',
    region: driver.caps.LEX_REGION,
    accessKeyId: driver.caps.LEX_ACCESS_KEY_ID,
    secretAccessKey: driver.caps.LEX_SECRET_ACCESS_KEY
  });
  const newBotData = {
    name: `${origBot ? origBot.name : 'Botium'}TrainingCopy${randomatic('Aa', 5)}`,
    childDirected: origBot ? origBot.childDirected : true,
    locale: origBot ? origBot.locale : 'en-US',
    voiceId: '',
    abortStatement: origBot ? origBot.abortStatement : {
      messages: [{
        content: "I'm sorry, I don't understand.",
        contentType: 'PlainText'
      }]
    },
    intents: []
  };
  const trainedIntents = [];
  for (const intent of intents || []) {
    const newIntentName = `${intent.intentName.replace(/[^A-Za-z]/gi, '')}Botium${randomatic('Aa', 5)}`;
    while (true) {
      try {
        const newIntent = await client.putIntent({
          name: newIntentName,
          fulfillmentActivity: {
            type: 'ReturnIntent'
          },
          sampleUtterances: lodash.uniq(intent.utterances.map(u => u.replace(/[^\w\s]/gi, '').replace(/[0-9]/gi, 'X').toLowerCase()).filter(u => u && u.length > 0)),
          slots: []
        }).promise();
        debug$2(`Lex Intent created: ${newIntent.name}`);
        trainedIntents.push({
          intentName: intent.intentName,
          mapFromIntentName: newIntentName
        });
        newBotData.intents.push({
          intentName: newIntent.name,
          intentVersion: newIntent.version
        });
        break;
      } catch (err) {
        debug$2(`Lex Intent creation ${newIntentName} failed, retry: ${err.message || err}`);
        await timeout$1(2000);
      }
    }
  }
  let newBot, newBotAlias;
  while (true) {
    try {
      newBot = await client.putBot(newBotData).promise();
      debug$2(`Lex Bot created: ${newBot.name}`);
      break;
    } catch (err) {
      debug$2(`Lex Bot creation ${newBotData.name} failed, retry: ${err.message || err}`);
      await timeout$1(2000);
    }
  }
  while (true) {
    try {
      newBotAlias = await client.putBotAlias({
        botName: newBot.name,
        botVersion: newBot.version,
        name: 'botiumdev'
      }).promise();
      debug$2(`Lex Bot Alias created: ${newBotAlias.name}`);
      break;
    } catch (err) {
      debug$2(`Lex Bot Alias creation botiumdev failed, retry: ${err.message || err}`);
      await timeout$1(2000);
    }
  }
  while (true) {
    const newBotStatus = await client.getBot({
      name: newBot.name,
      versionOrAlias: newBot.version
    }).promise();
    debug$2(`Lex Bot Status received: ${newBotStatus.status}`);
    if (newBotStatus.status === 'READY') break;
    if (newBotStatus.status === 'FAILED') throw new Error('Lex Bot Status is FAILED');
    await timeout$1(2000);
  }
  return {
    trainedIntents,
    caps: Object.assign({}, getCaps(caps), {
      LEX_PROJECT_NAME: newBot.name,
      LEX_PROJECT_ALIAS: newBotAlias.name
    }),
    origBot,
    tempBot: newBot,
    tempBotAlias: newBotAlias
  };
};
const cleanupIntentUtterances$1 = async ({
  caps
}, {
  caps: trainCaps,
  tempBot,
  tempBotAlias
}) => {
  const driver = new botiumCore.BotDriver(getCaps(Object.assign(caps || {}, trainCaps || {})));
  const client = new awsSdk.LexModelBuildingService({
    apiVersion: '2017-04-19',
    region: driver.caps.LEX_REGION,
    accessKeyId: driver.caps.LEX_ACCESS_KEY_ID,
    secretAccessKey: driver.caps.LEX_SECRET_ACCESS_KEY
  });
  while (true) {
    try {
      await client.deleteBotAlias({
        botName: tempBot.name,
        name: tempBotAlias.name
      }).promise();
      debug$2(`Lex Bot Alias deleted: ${tempBotAlias.name}`);
      break;
    } catch (err) {
      debug$2(`Lex Bot Alias deletion ${tempBotAlias.name} failed: ${err.message || err}`);
      await timeout$1(2000);
    }
  }
  while (true) {
    try {
      await client.deleteBot({
        name: tempBot.name
      }).promise();
      debug$2(`Lex Bot deleted: ${tempBot.name}`);
      break;
    } catch (err) {
      debug$2(`Lex Bot deletion ${tempBot.name} failed, retry: ${err.message || err}`);
      await timeout$1(2000);
    }
  }
  for (const intent of tempBot.intents) {
    while (true) {
      try {
        await client.deleteIntent({
          name: intent.intentName
        }).promise();
        debug$2(`Lex Intent deleted: ${intent.intentName}`);
        break;
      } catch (err) {
        debug$2(`Lex Intent deletion ${intent.intentName} failed, retry: ${err.message || err}`);
        await timeout$1(2000);
      }
    }
  }
};
var nlp = {
  extractIntentUtterances: extractIntentUtterances$1,
  trainIntentUtterances: trainIntentUtterances$1,
  cleanupIntentUtterances: cleanupIntentUtterances$1
};

const debug$1 = debug$5('botium-connector-lex-import');
const {
  Defaults
} = connector;
const {
  paginatedCall: paginatedCall$1,
  loadSlotTypes,
  loadCustomSlotTypes,
  extractSlotNames,
  expandSlotType
} = slottypes;
const importIntents = async ({
  caps,
  buildconvos,
  buildentities
}) => {
  const driver = new botiumCore.BotDriver(caps);
  const botVersion = driver.caps.LEX_VERSION;
  const botName = driver.caps.LEX_PROJECT_NAME;
  const botAlias = driver.caps.LEX_PROJECT_ALIAS;
  const client = botVersion === 'V1' ? new awsSdk.LexModelBuildingService({
    apiVersion: '2017-04-19',
    region: driver.caps.LEX_REGION,
    accessKeyId: driver.caps.LEX_ACCESS_KEY_ID,
    secretAccessKey: driver.caps.LEX_SECRET_ACCESS_KEY
  }) : new awsSdk.LexModelsV2({
    apiVersion: '2020-08-07',
    region: driver.caps.LEX_REGION,
    accessKeyId: driver.caps.LEX_ACCESS_KEY_ID,
    secretAccessKey: driver.caps.LEX_SECRET_ACCESS_KEY
  });
  if (botVersion === 'V2' && !driver.caps.LEX_PROJECT_VERSION) {
    const aliasResponse = await client.describeBotAlias({
      botId: botName,
      botAliasId: botAlias
    }).promise();
    if (aliasResponse && aliasResponse.botVersion) {
      driver.caps.LEX_PROJECT_VERSION = aliasResponse.botVersion;
    }
  }
  const builtinSlotTypes = await loadSlotTypes('en-us');
  debug$1(`Loaded ${Object.keys(builtinSlotTypes).length} built-in slot types`);
  const customSlotTypes = await loadCustomSlotTypes(client, driver.caps);
  debug$1(`Loaded ${Object.keys(customSlotTypes).length} custom slot types`);
  let intents = [];
  if (botVersion === 'V1') {
    intents = (await client.getBot({
      name: botName,
      versionOrAlias: botAlias
    }).promise()).intents || [];
  } else {
    intents = (await paginatedCall$1(client.listIntents.bind(client), d => d.intentSummaries, {
      botId: driver.caps.LEX_PROJECT_NAME,
      botVersion: driver.caps.LEX_PROJECT_VERSION,
      localeId: driver.caps.LEX_LOCALE || Defaults.LEX_LOCALE
    })) || [];
  }
  const convos = [];
  const utterances = [];
  for (const intent of intents) {
    let sampleUtterances = [];
    let slots = [];
    if (botVersion === 'V1') {
      const botIntent = await client.getIntent({
        version: intent.intentVersion,
        name: intent.intentName
      }).promise();
      sampleUtterances = botIntent.sampleUtterances || [];
      slots = botIntent.slots || [];
    } else {
      const botIntent = await client.describeIntent({
        botId: driver.caps.LEX_PROJECT_NAME,
        botVersion: driver.caps.LEX_PROJECT_VERSION,
        localeId: driver.caps.LEX_LOCALE || Defaults.LEX_LOCALE,
        intentId: intent.intentId
      }).promise();
      sampleUtterances = botIntent.sampleUtterances && botIntent.sampleUtterances.map(s => s.utterance) || [];
      const botSlots = (await paginatedCall$1(client.listSlots.bind(client), d => d.slotSummaries, {
        botId: driver.caps.LEX_PROJECT_NAME,
        botVersion: driver.caps.LEX_PROJECT_VERSION,
        localeId: driver.caps.LEX_LOCALE || Defaults.LEX_LOCALE,
        intentId: intent.intentId
      })) || [];
      slots = botSlots.map(s => ({
        name: s.slotName,
        slotType: s.slotTypeId
      }));
    }
    const userExamples = {};
    const userExamplesSlotNames = {};
    for (const userExample of sampleUtterances) {
      const slotNames = extractSlotNames(userExample);
      if (slotNames.length > 0) {
        debug$1(`Filling slots ${slotNames.join('|')} in user example "${userExample}"`);
        const expandedUserExamples = slotNames.reduce((result, slotName) => {
          const slot = slots.find(s => s.name === slotName);
          if (slot) {
            if (customSlotTypes[slot.slotType]) {
              return result.reduce((expanded, resultUtt) => {
                return [...expanded, ...expandSlotType(resultUtt, slot.name, customSlotTypes[slot.slotType])];
              }, []);
            }
            const builtinSlotTypeName = Object.keys(builtinSlotTypes).find(st => st.toLowerCase() === slot.slotType.toLowerCase());
            if (builtinSlotTypeName) {
              return result.reduce((expanded, resultUtt) => {
                return [...expanded, ...expandSlotType(resultUtt, slot.name, builtinSlotTypes[builtinSlotTypeName])];
              }, []);
            }
          }
          return result;
        }, [userExample]);
        const uttSuffix = `_${slotNames.join('_')}`;
        userExamplesSlotNames[uttSuffix] = slotNames;
        userExamples[uttSuffix] = userExamples[uttSuffix] ? userExamples[uttSuffix].concat(expandedUserExamples) : expandedUserExamples;
      } else {
        userExamplesSlotNames[''] = [];
        userExamples[''] = userExamples[''] || [];
        userExamples[''].push(userExample);
      }
    }
    if (buildconvos && buildentities) {
      for (const uttSuffix of Object.keys(userExamples)) {
        utterances.push({
          name: intent.intentName + uttSuffix,
          utterances: userExamples[uttSuffix]
        });
        const convo = {
          header: {
            name: intent.intentName + uttSuffix
          },
          conversation: [{
            sender: 'me',
            messageText: intent.intentName + uttSuffix
          }, {
            sender: 'bot',
            asserters: [{
              name: 'INTENT',
              args: [intent.intentName]
            }]
          }]
        };
        if (userExamplesSlotNames[uttSuffix].length > 0) {
          convo.conversation[1].asserters.push({
            name: 'ENTITIES',
            args: userExamplesSlotNames[uttSuffix]
          });
        }
        convos.push(convo);
      }
    } else if (buildconvos) {
      utterances.push({
        name: intent.intentName,
        utterances: Object.keys(userExamples).reduce((all, k) => all.concat(userExamples[k]), [])
      });
      const convo = {
        header: {
          name: intent.intentName
        },
        conversation: [{
          sender: 'me',
          messageText: intent.intentName
        }, {
          sender: 'bot',
          asserters: [{
            name: 'INTENT',
            args: [intent.intentName]
          }]
        }]
      };
      convos.push(convo);
    } else {
      utterances.push({
        name: intent.intentName,
        utterances: Object.keys(userExamples).reduce((all, k) => all.concat(userExamples[k]), [])
      });
    }
  }
  return {
    convos,
    utterances
  };
};
var _import = {
  importHandler: ({
    caps,
    buildconvos,
    ...rest
  } = {}) => importIntents({
    caps,
    buildconvos,
    ...rest
  }),
  importArgs: {
    caps: {
      describe: 'Capabilities',
      type: 'json',
      skipCli: true
    },
    buildconvos: {
      describe: 'Build convo files with intent asserters',
      type: 'boolean',
      default: true
    },
    buildentities: {
      describe: 'Add entity asserters to convo files',
      type: 'boolean',
      default: false
    }
  }
};

const debug = debug$5('botium-connector-lex-export');
const timeout = ms => new Promise(resolve => setTimeout(resolve, ms));
const exportIntents = async ({
  caps,
  uploadmode,
  newBotName,
  newBotAliasName,
  waitforready
}, {
  convos,
  utterances
}, {
  statusCallback
}) => {
  const driver = new botiumCore.BotDriver(caps);
  if (driver.caps.LEX_VERSION !== 'V1') throw new Error('Only supported for Lex Version 1');
  const status = (log, obj) => {
    debug(log, obj);
    if (statusCallback) statusCallback(log, obj);
  };
  const botName = driver.caps.LEX_PROJECT_NAME;
  const botAlias = driver.caps.LEX_PROJECT_ALIAS;
  const client = new awsSdk.LexModelBuildingService({
    apiVersion: '2017-04-19',
    region: driver.caps.LEX_REGION,
    accessKeyId: driver.caps.LEX_ACCESS_KEY_ID,
    secretAccessKey: driver.caps.LEX_SECRET_ACCESS_KEY
  });
  const bot = await client.getBot({
    name: botName,
    versionOrAlias: botAlias
  }).promise();
  if (uploadmode === 'copy') {
    const nameExt = randomatic('Aa', 5);
    const newBotData = Object.assign({}, lodash.omit(bot, ['name', 'status', 'failureReason', 'lastUpdatedDate', 'createdDate', 'checksum', 'version', 'intents']), {
      name: newBotName || `Copy_Of_${bot.name}_${nameExt}`,
      intents: []
    });
    for (const utt of utterances) {
      const newIntentData = {
        name: utt.name,
        fulfillmentActivity: {
          type: 'ReturnIntent'
        },
        sampleUtterances: lodash.uniq(utt.utterances.map(u => u.replace(/[^\w\s]/gi, '').replace(/[0-9]/gi, 'X').toLowerCase()).filter(u => u && u.length > 0)),
        slots: []
      };
      try {
        const existingBotIntent = await client.getIntent({
          version: '$LATEST',
          name: utt.name
        }).promise();
        Object.assign(newIntentData, lodash.omit(existingBotIntent, ['sampleUtterances', 'lastUpdatedDate', 'createdDate', 'version']));
      } catch (err) {
        debug(`Lex Intent ${utt.name} failed to load: ${err.message}. Will be created new.`);
      }
      while (true) {
        try {
          const newIntent = await client.putIntent(newIntentData).promise();
          status(`Lex Intent uploaded ${newIntent.name}/${newIntent.version}`, {
            botName: newBotData.name
          });
          newBotData.intents.push({
            intentName: newIntent.name,
            intentVersion: newIntent.version
          });
          break;
        } catch (err) {
          debug(`Lex Intent creation ${utt.name} failed, retry: ${err.message || err}`);
          await timeout(2000);
        }
      }
    }
    let newBot, newBotAlias;
    while (true) {
      try {
        newBot = await client.putBot(newBotData).promise();
        status(`Lex Bot created ${newBot.name}/${newBot.version}`, {
          botName: newBotData.name,
          botVersion: newBot.version
        });
        break;
      } catch (err) {
        debug(`Lex Bot creation ${newBotData.name} failed, retry: ${err.message || err}`);
        await timeout(2000);
      }
    }
    while (true) {
      try {
        newBotAlias = await client.putBotAlias({
          botName: newBot.name,
          botVersion: newBot.version,
          name: newBotAliasName
        }).promise();
        status(`Lex Bot Alias created ${newBotAlias.name}`, {
          botName: newBotData.name,
          botVersion: newBot.version,
          botAlias: newBotAlias.name
        });
        break;
      } catch (err) {
        debug(`Lex Bot Alias creation botiumdev failed, retry: ${err.message || err}`);
        await timeout(2000);
      }
    }
    if (waitforready) {
      status(`Waiting for Lex Bot ${newBotData.name} training`, {
        botName: newBotData.name,
        botVersion: newBot.version,
        botAlias: newBotAlias.name
      });
      while (true) {
        const newBotStatus = await client.getBot({
          name: newBot.name,
          versionOrAlias: newBot.version
        }).promise();
        debug(`Lex Bot Status received: ${newBotStatus.status}`);
        if (newBotStatus.status === 'READY') break;
        if (newBotStatus.status === 'FAILED') throw new Error('Lex Bot Status is FAILED');
        await timeout(2000);
      }
      status(`Lex Bot ${newBotData.name} ready for use`, {
        botName: newBotData.name,
        botVersion: newBot.version,
        botAlias: newBotAlias.name
      });
    }
    const newCaps = lodash.pickBy(driver.caps, (value, key) => key.startsWith('LEX_'));
    newCaps.LEX_PROJECT_NAME = newBotData.name;
    newCaps.LEX_PROJECT_ALIAS = newBotAlias.name;
    return {
      caps: newCaps,
      botName: newBotData.name,
      botVersion: newBot.version,
      botAlias: newBotAlias.name
    };
  } else {
    for (const utt of utterances) {
      const newIntentData = {
        name: utt.name,
        fulfillmentActivity: {
          type: 'ReturnIntent'
        },
        sampleUtterances: lodash.uniq(utt.utterances.map(u => u.replace(/[^\w\s]/gi, '').replace(/[0-9]/gi, 'X').toLowerCase()).filter(u => u && u.length > 0)),
        slots: []
      };
      try {
        const existingBotIntent = await client.getIntent({
          version: '$LATEST',
          name: utt.name
        }).promise();
        Object.assign(newIntentData, lodash.omit(existingBotIntent, ['sampleUtterances', 'lastUpdatedDate', 'createdDate', 'version']));
        newIntentData.sampleUtterances = lodash.uniq(newIntentData.sampleUtterances.concat(existingBotIntent.sampleUtterances));
      } catch (err) {
        debug(`Lex Intent ${utt.name} failed to load: ${err.message}. Will be created new.`);
      }
      while (true) {
        try {
          const newIntent = await client.putIntent(newIntentData).promise();
          status(`Lex Intent uploaded ${newIntent.name}/${newIntent.version}`, {
            botName
          });
          break;
        } catch (err) {
          debug(`Lex Intent creation ${utt.name} failed, retry: ${err.message || err}`);
          await timeout(2000);
        }
      }
    }
    if (waitforready) {
      status(`Waiting for Lex Bot ${botName} training`, {
        botName
      });
      while (true) {
        const newBotStatus = await client.getBot({
          name: botName,
          versionOrAlias: botAlias
        }).promise();
        debug(`Lex Bot Status received: ${newBotStatus.status}`);
        if (newBotStatus.status === 'READY') break;
        if (newBotStatus.status === 'FAILED') throw new Error('Lex Bot Status is FAILED');
        await timeout(2000);
      }
      status(`Lex Bot ${botName} ready for use`, {
        botName
      });
    }
    const newCaps = lodash.pickBy(driver.caps, (value, key) => key.startsWith('LEX_'));
    return {
      caps: newCaps,
      botName
    };
  }
};
var _export = {
  exportHandler: ({
    caps,
    uploadmode,
    newBotName,
    newBotAliasName,
    waitforready,
    ...rest
  } = {}, {
    convos,
    utterances
  } = {}, {
    statusCallback
  } = {}) => exportIntents({
    caps,
    uploadmode,
    newBotName,
    newBotAliasName,
    waitforready,
    ...rest
  }, {
    convos,
    utterances
  }, {
    statusCallback
  }),
  exportArgs: {
    caps: {
      describe: 'Capabilities',
      type: 'json',
      skipCli: true
    },
    uploadmode: {
      describe: 'Copy Lex Bot and create new intent version with user examples, or append user examples to existing intents only',
      choices: ['copy', 'append'],
      default: 'copy'
    },
    newBotName: {
      describe: 'New Lex Bot name (if not given will be generated)',
      type: 'string'
    },
    newBotAliasName: {
      describe: 'New Lex Bot alias',
      type: 'string',
      default: 'botiumdev'
    },
    waitforready: {
      describe: 'Wait until Lex Bot is ready',
      type: 'boolean',
      default: false
    }
  }
};

const {
  extractIntentUtterances,
  trainIntentUtterances,
  cleanupIntentUtterances
} = nlp;
const {
  importHandler,
  importArgs
} = _import;
const {
  exportHandler,
  exportArgs
} = _export;
const {
  paginatedCall
} = slottypes;
var botiumConnectorLex = {
  PluginVersion: 1,
  PluginClass: connector,
  Import: {
    Handler: importHandler,
    Args: importArgs
  },
  Export: {
    Handler: exportHandler,
    Args: exportArgs
  },
  NLP: {
    ExtractIntentUtterances: extractIntentUtterances,
    TrainIntentUtterances: trainIntentUtterances,
    CleanupIntentUtterances: cleanupIntentUtterances
  },
  PluginDesc: {
    name: 'Amazon Lex',
    provider: 'Amazon',
    features: {
      intentResolution: true,
      entityResolution: true
    },
    helperText: 'See section <b>Connecting Amazon Lex to Botium</b> in the <a href="https://github.com/codeforequity-at/botium-connector-lex" target="_blank" rel="noopener noreferrer">Github Repository</a> of the connector for instructions how to get an IAM user.',
    capabilities: [{
      name: 'LEX_VERSION',
      label: 'Lex Version',
      type: 'choice',
      required: true,
      choices: [{
        key: 'V1',
        name: 'V1'
      }, {
        key: 'V2',
        name: 'V2'
      }]
    }, {
      name: 'LEX_ACCESS_KEY_ID',
      label: 'IAM Access Key',
      type: 'string',
      required: true
    }, {
      name: 'LEX_SECRET_ACCESS_KEY',
      label: 'IAM Secret Key',
      type: 'secret',
      required: true
    }, {
      name: 'LEX_REGION',
      label: 'Amazon Region Code',
      type: 'choice',
      required: true,
      choices: [{
        key: 'us-east-1',
        name: 'US East (N. Virginia)'
      }, {
        key: 'us-west-2',
        name: 'US West (Oregon)'
      }, {
        key: 'af-south-1',
        name: 'Africa (Cape Town)'
      }, {
        key: 'ap-southeast-1',
        name: 'Asia Pacific (Singapore)'
      }, {
        key: 'ap-northeast-2',
        name: 'Asia Pacific (Seoul)'
      }, {
        key: 'ap-southeast-2',
        name: 'Asia Pacific (Sydney)'
      }, {
        key: 'ap-northeast-1',
        name: 'Asia Pacific (Tokyo)'
      }, {
        key: 'eu-central-1',
        name: 'Europe (Frankfurt)'
      }, {
        key: 'eu-west-1',
        name: 'Europe (Ireland)'
      }, {
        key: 'eu-west-2',
        name: 'Europe (London)'
      }, {
        key: 'ca-central-1',
        name: 'Canada (Central)'
      }]
    }, {
      name: 'LEX_PROJECT_NAME',
      label: 'Name of the Lex Bot (project name)',
      type: 'query',
      required: true,
      query: async caps => {
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_VERSION === 'V1') {
          const client = new awsSdk.LexModelBuildingService({
            apiVersion: '2017-04-19',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const bots = await paginatedCall(client.getBots.bind(client), r => r.bots);
          if (bots && bots.length > 0) {
            return bots.map(b => ({
              key: b.name,
              name: b.name,
              description: b.description
            }));
          }
        }
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_VERSION === 'V2') {
          const client = new awsSdk.LexModelsV2({
            apiVersion: '2020-08-07',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const botSummaries = await paginatedCall(client.listBots.bind(client), r => r.botSummaries);
          if (botSummaries && botSummaries.length > 0) {
            return botSummaries.map(b => ({
              key: b.botId,
              name: b.botName,
              description: b.description
            }));
          }
        }
      }
    }, {
      name: 'LEX_PROJECT_ALIAS',
      label: 'Alias of the Lex Bot (see publishing)',
      type: 'query',
      required: true,
      query: async caps => {
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_PROJECT_NAME && caps.LEX_VERSION === 'V1') {
          const client = new awsSdk.LexModelBuildingService({
            apiVersion: '2017-04-19',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const botAliases = await paginatedCall(client.getBotAliases.bind(client), r => r.BotAliases, {
            botName: caps.LEX_PROJECT_NAME
          });
          if (botAliases && botAliases.length > 0) {
            return botAliases.map(b => ({
              key: b.name,
              name: b.name,
              description: b.description
            }));
          }
        }
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_PROJECT_NAME && caps.LEX_VERSION === 'V2') {
          const client = new awsSdk.LexModelsV2({
            apiVersion: '2020-08-07',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const botAliasSummaries = await paginatedCall(client.listBotAliases.bind(client), r => r.botAliasSummaries, {
            botId: caps.LEX_PROJECT_NAME
          });
          if (botAliasSummaries && botAliasSummaries.length > 0) {
            return botAliasSummaries.map(b => ({
              key: b.botAliasId,
              name: b.botAliasName,
              description: b.description
            }));
          }
        }
      }
    }, {
      name: 'LEX_LOCALE',
      label: 'Locale of the Lex Bot (V2 only)',
      type: 'query',
      query: async caps => {
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_PROJECT_NAME && caps.LEX_PROJECT_ALIAS && caps.LEX_VERSION === 'V2') {
          const client = new awsSdk.LexModelsV2({
            apiVersion: '2020-08-07',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const aliasResponse = await client.describeBotAlias({
            botId: caps.LEX_PROJECT_NAME,
            botAliasId: caps.LEX_PROJECT_ALIAS
          }).promise();
          if (aliasResponse && aliasResponse.botVersion) {
            const botLocaleSummaries = await paginatedCall(client.listBotLocales.bind(client), r => r.botLocaleSummaries, {
              botId: caps.LEX_PROJECT_NAME,
              botVersion: aliasResponse.botVersion
            });
            if (botLocaleSummaries && botLocaleSummaries.length > 0) {
              return botLocaleSummaries.map(b => ({
                key: b.localeId,
                name: b.localeName,
                description: b.description
              }));
            }
          }
        }
      }
    }, {
      name: 'LEX_ACCEPT',
      label: 'Audio Response Type',
      description: 'Set the response audio type to the expected format (only applicable for voice tests with audio input)',
      type: 'choice',
      required: false,
      advanced: true,
      choices: [{
        key: 'text/plain; charset=utf-8',
        name: 'Text'
      }, {
        key: 'audio/mpeg',
        name: 'MP3 Audio (*.mp3)'
      }, {
        key: 'audio/ogg',
        name: 'Ogg Vorbis Audio (*.ogg)'
      }, {
        key: 'audio/pcm',
        name: 'PCM Audio (*.wav)'
      }]
    }],
    actions: [{
      name: 'GetAgentMetaData',
      description: 'GetAgentMetaData',
      run: async caps => {
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_PROJECT_NAME && caps.LEX_PROJECT_ALIAS && caps.LEX_VERSION === 'V1') {
          const client = new awsSdk.LexModelBuildingService({
            apiVersion: '2017-04-19',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const bot = await client.getBot({
            name: caps.LEX_PROJECT_NAME,
            versionOrAlias: caps.LEX_PROJECT_ALIAS
          }).promise();
          return {
            name: bot.name,
            description: bot.description,
            metadata: bot
          };
        }
        if (caps && caps.LEX_ACCESS_KEY_ID && caps.LEX_SECRET_ACCESS_KEY && caps.LEX_REGION && caps.LEX_PROJECT_NAME && caps.LEX_VERSION === 'V2') {
          const client = new awsSdk.LexModelsV2({
            apiVersion: '2020-08-07',
            region: caps.LEX_REGION,
            accessKeyId: caps.LEX_ACCESS_KEY_ID,
            secretAccessKey: caps.LEX_SECRET_ACCESS_KEY
          });
          const botResponse = await client.describeBot({
            botId: caps.LEX_PROJECT_NAME
          }).promise();
          return {
            name: botResponse.botName,
            description: botResponse.description,
            metadata: botResponse
          };
        }
      }
    }]
  }
};
var botiumConnectorLex_1 = botiumConnectorLex.PluginVersion;
var botiumConnectorLex_2 = botiumConnectorLex.PluginClass;
var botiumConnectorLex_3 = botiumConnectorLex.Import;
var botiumConnectorLex_4 = botiumConnectorLex.Export;
var botiumConnectorLex_5 = botiumConnectorLex.NLP;
var botiumConnectorLex_6 = botiumConnectorLex.PluginDesc;

export { botiumConnectorLex_4 as Export, botiumConnectorLex_3 as Import, botiumConnectorLex_5 as NLP, botiumConnectorLex_2 as PluginClass, botiumConnectorLex_6 as PluginDesc, botiumConnectorLex_1 as PluginVersion, botiumConnectorLex as default };
//# sourceMappingURL=botium-connector-lex-es.js.map
